'****************************************************************
'*  Name    : SYS_18F2X-4XK22.INC                               *
'*  Author  : [Alberto Freixanet Solsona]                       *
'*  Notice  : Copyright (c) 2005 [---]                          *
'*          : All Rights Reserved                               *
'*  Date    : 23/08/2012                                        *
'*  Version : 1.0                                               *
'*  Notes   : Flags definitions of PIC 18F2X-4XK22              *
'*          :                                                   *
'****************************************************************
' 23/08/2012: V1.0
' 23/12/2015: V1.1
' Fixed a tipo with the preprocessor
' Add bit: Symbol F_NOT_RBPU = INTCON2.7       'PORTB Pull-up Enable Bit
' Fixed error in the SSP2CON2 register.
' 25/02/2016
' Added F_TXIF = F_TX1IF
'-------------------------------------------------------------------------------
'$Define __SSP1CON2
'$Define __SSP2CON2
$define __CTMUCONH      ' Fixes in Proton V3548

'-------------------------------------------------------------------------------
'22/08/2012
'OSCCON: OSCILLATOR CONTROL REGISTER
    Symbol F_IDLEN = OSCCON.7   ' Idle Enable bits
        '1 = Device enters Idle mode on SLEEP instruction
        '0 = Device enters Sleep mode on SLEEP instruction
    'bit 6-4 IRCF<2:0>: Internal RC Oscillator Frequency Select bits(2)
    Symbol F_IRCF2 = OSCCON.6     ' Internal Oscillator Frequency Select bits
    Symbol F_IRCF1 = OSCCON.5     ' Internal Oscillator Frequency Select bits
    Symbol F_IRCF0 = OSCCON.4     ' Internal Oscillator Frequency Select bits
        '111 = HFINTOSC  (16 MHz)
        '110 = HFINTOSC/2  (8 MHz)
        '101 = HFINTOSC/4  (4 MHz)
        '100 = HFINTOSC/8  (2 MHz)
        '011 = HFINTOSC/16  (1 MHz)(3)
        'If INTSRC = 0 and MFIOSEL = 0:
            '010 = HFINTOSC/32  (500 kHz)
            '001 = HFINTOSC/64  (250 kHz)
            '000 = LFINTOSC  (31.25 kHz)
        'If INTSRC = 1 and MFIOSEL = 0:
            '010 = HFINTOSC/32  (500 kHz)
            '001 = HFINTOSC/64  (250 kHz)
            '000 = HFINTOSC/512  (31.25 kHz)
        'If INTSRC = 0 and MFIOSEL = 1:
            '010 = MFINTOSC  (500 kHz)
            '001 = MFINTOSC/2  (250 kHz)
            '000 = LFINTOSC  (31.25 kHz)
        'If INTSRC = 1 and MFIOSEL = 1:
            '010 = MFINTOSC  (500 kHz)
            '001 = MFINTOSC/2  (250 kHz)
            '000 = MFINTOSC/16  (31.25 kHz)
    Symbol F_OSTS = OSCCON.3    ' Oscillator Start-up Time-out Status bit    
        '1 = Device is running from the clock defined by FOSC<3:0> of the CONFIG1H register
        '0 = Device is running from the internal oscillator (HFINTOSC, MFINTOSC or LFINTOSC)
    Symbol F_IOFS = OSCCON.2    ' INTOSC Frequency Stable bit
        '1 = HFINTOSC frequency is stable
        '0 = HFINTOSC frequency is not stable
    Symbol F_SCS1 = OSCCON.1    ' System Clock Select bit
    Symbol F_SCS0 = OSCCON.0    ' System Clock Select bit
        '1x = Internal oscillator block
        '01 = Secondary (SOSC) oscillator
        '00 = Primary clock (determined by FOSC<3:0> in CONFIG1H).
'
'Note   1: Reset state depends on state of the IESO Configuration bit.
'       2: INTOSC source may be determined by the INTSRC bit in OSCTUNE and the MFIOSEL bit in OSCCON2.
'       3: Default output frequency of HFINTOSC on Reset.
'-------------------------------------------------------------------------------
'22/08/2012
'OSCCON2: OSCILLATOR CONTROL REGISTER 2
    Symbol F_PLLRDY = OSCCON2.7         'PLL Run STATUS Bit
        '1 = System clock comes from 4xPLL
        '0 = System clock comes from an oscillator, other than 4xPLL
    Symbol F_SOSCRUN = OSCCON2.6        'SOSC Run STATUS Bit
        '1 = System clock comes from secondary SOSC
        '0 = System clock comes from an oscillator, other than SOSC
    'bit 5 Unimplemented: Read as 0.
    Symbol F_MFIOSEL = OSCCON2.4        'MFINTOSC Select Bit
        '1 = MFINTOSC is used in place of HFINTOSC frequencies of 500 kHz, 250 kHz and 31.25 kHz
        '0 = MFINTOSC is not used
    Symbol F_SOSCGO = OSCCON2.3         '(1): Secondary Oscillator Start Control Bit
        '1 = Secondary oscillator is enabled.
        '0 = Secondary oscillator is shut off if no other sources are requesting it.
    Symbol F_PRISD = OSCCON2.2          'Primary Oscillator Drive Circuit Shutdown Bit
        '1 = Oscillator drive circuit on
        '0 = Oscillator drive circuit off (zero power)
    Symbol F_MFIOFS = OSCCON2.1         'MFINTOSC Frequency Stable Bit
        '1 = MFINTOSC is stable
        '0 = MFINTOSC is not stable
    Symbol F_LFIOFS = OSCCON2.1         'LFINTOSC Frequency Stable Bit
        '1 = LFINTOSC is stable
        '0 = LFINTOSC is not stable
'
'Note 1: The SOSCGO bit is only reset on a POR Reset.
'-------------------------------------------------------------------------------
'22/08/2012
'OSCTUNE: OSCILLATOR TUNING REGISTER
    Symbol F_INTSRC = OSCTUNE.7         'Internal Oscillator Low-Frequency Source Select Bit
        '1 = 31.25 kHz device clock derived from the MFINTOSC or HFINTOSC source
        '0 = 31.25 kHz device clock derived directly from LFINTOSC internal oscillator
    Symbol F_PLLEN = OSCTUNE.6          'Frequency Multiplier 4xPLL For HFINTOSC Enable Bit(1)
        '1 = PLL enabled for HFINTOSC (8 MHz and 16 MHz only)
        '0 = PLL disabled
    Symbol F_TUN5 = OSCTUNE.5           'Frequency Tuning bits  use To adjust MFINTOSC And HFINTOSC frequenci
        '011111 = Maximum frequency
        '011110 =
        '  
        '000001 =
        '000000 = Oscillator module (HFINTOSC and MFINTOSC) are running at the factory calibrated
        'frequency.
        '111111 =
        '  
        '100000 = Minimum frequency
    Symbol F_TUN4 = OSCTUNE.4
    Symbol F_TUN3 = OSCTUNE.3
    Symbol F_TUN2 = OSCTUNE.2
    Symbol F_TUN1 = OSCTUNE.1
    Symbol F_TUN05 = OSCTUNE.0
'                
'Note 1: The PLLEN bit is active only when the HFINTOSC is the primary clock source
'         (FOSC<2:0> = 100X) and
' the selected frequency is 8 MHz or 16 MHz (IRCF<2:0> = 11x). Otherwise, the PLLEN bit
' is unavailable and always reads 0.
'-------------------------------------------------------------------------------
'22/08/2012
'PMD0: PERIPHERAL MODULE DISABLE REGISTER 0
    Symbol F_UART2MD = PMD0.7       'UART2 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_UART1MD = PMD0.6       'UART1 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR6MD = PMD0.5        'Timer6 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR5MD = PMD0.4        'Timer5 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR4MD = PMD0.3        'Timer4 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR3MD = PMD0.2        'Timer3 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR2MD = PMD0.1        'Timer2 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_TMR1MD = PMD0.0        'Timer1 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
'-------------------------------------------------------------------------------
'22/08/2012
'PMD1: PERIPHERAL MODULE DISABLE REGISTER 1
    Symbol F_MSSP2MD = PMD1.7       'MSSP2 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_MSSP1MD = PMD1.6       'MSSP1 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    'bit 5 Unimplemented: Read as 0
    Symbol F_CCP5MD = PMD1.4        'CCP5 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CCP4MD = PMD1.3        'CCP4 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CCP3MD = PMD1.2        'CCP3 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CCP2MD = PMD1.1        'CCP2 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CCP1MD = PMD1.0        'CCP1 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power

'-------------------------------------------------------------------------------
'22/08/2012
'PMD2: PERIPHERAL MODULE DISABLE REGISTER 2
    'bit 7-4 Unimplemented: Read as 0
    Symbol F_CTMUMD = PMD2.3        'CTMU Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CMP2MD = PMD2.2        'Comparator C2 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_CMP1MD = PMD2.1     'Comparator C1 Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
    Symbol F_ADCMD = PMD2.0     'ADC Peripheral Module Disable Control Bit
        '1 = Module is disabled, Clock Source is disconnected, module does not draw digital power
        '0 = Module is enabled, Clock Source is connected, module draws digital power
'-------------------------------------------------------------------------------
'22/08/2012
'RCON: RESET CONTROL REGISTER
    Symbol F_IPEN = RCON.7      'Interrupt Priority Enable Bit
        '1 = Enable priority levels on interrupts
        '0 = Disable priority levels on interrupts (PIC16CXXX Compatibility mode)
    Symbol F_SBOREN = RCON.6        'BOR Software Enable Bit(1)
        'If BOREN<1:0> = 01:
            '1 = BOR is enabled
            '0 = BOR is disabled
        'If BOREN<1:0> = 00, 10 or 11:
            'Bit is disabled and read as 0.
    'bit 5 Unimplemented: Read as 0
    Symbol F_RI = RCON.4        'Reset Instruction Flag Bit
        '1 = The RESET instruction was not executed (set by firmware or Power-on Reset)
        '0 = The RESET instruction was executed causing a device Reset
        ' (must be set in firmware after a code-executed Reset occurs)
    Symbol F_TO = RCON.3        'Watchdog Time-out Flag Bit
        '1 = Set by power-up, CLRWDT instruction or SLEEP instruction
        '0 = A WDT time-out occurred
    Symbol F_PD = RCON.2        'Power-down Detection Flag Bit
        '1 = Set by power-up or by the CLRWDT instruction
        '0 = Set by execution of the SLEEP instruction
    Symbol F_POR = RCON.1       'Power-on Reset STATUS Bit(2)
        '1 = No Power-on Reset occurred
        '0 = A Power-on Reset occurred (must be set in software after a Power-on Reset occurs)
    Symbol F_BOR = RCON.0       'Brown-out Reset STATUS Bit(3)
        '1 = A Brown-out Reset has not occurred (set by firmware only)
        '0 = A Brown-out Reset occurred (must be set by firmware after a POR or Brown-out Reset occurs)
'
'Note   1: When CONFIG2L[2:1] = 01, then the SBOREN Reset state is 1; otherwise, it is 0.
'       2: The actual Reset value of POR is determined by the type of device Reset.
'          See the notes following this register and Section 4.6 Reset State of Registers
'          for additional information.
'       3: See Table 4-1.
'-------------------------------------------------------------------------------
'22/08/2012
'STKPTR: STACK POINTER REGISTER
    Symbol F_STKFUL = STKPTR.7      'Stack Full Flag Bit(1)
        '1 = Stack became full or overflowed
        '0 = Stack has not become full or overflowed
    Symbol F_STKUNF = STKPTR.6      'Stack Underflow Flag Bit(1)
        '1 = Stack Underflow occurred
        '0 = Stack Underflow did not occur
    'bit 5 Unimplemented: Read as 0
    'bit 4-0 STKPTR<4:0>: Stack Pointer Location bits
    Symbol F_STKPTR4 = STKPTR.4     '<4:0>: Stack Pointer Location bits
    Symbol F_STKPTR3 = STKPTR.3     '<4:0>: Stack Pointer Location bits
    Symbol F_STKPTR2 = STKPTR.2     '<4:0>: Stack Pointer Location bits
    Symbol F_STKPTR1 = STKPTR.1     '<4:0>: Stack Pointer Location bits
    Symbol F_STKPTR0 = STKPTR.0     '<4:0>: Stack Pointer Location bits
'
'Note 1: Bit 7 and bit 6 are cleared by user software or by a POR.
'-------------------------------------------------------------------------------
'STATUS: STATUS REGISTER
    ' bit 7-5 Unimplemented: Read as 0
    Symbol F_N =    STATUS.4    ' Negative bit
        ' This bit is used for signed arithmetic (twos complement). It indicates whether the result was negative
        ' (ALU MSB = 1).
        ' 1 = Result was negative
        ' 0 = Result was positive
    Symbol F_OV =   STATUS.3    ' Overflow bit
        ' This bit is used for signed arithmetic (twos complement).
        ' It indicates an overflow of the 7-bit magnitude
        ' which causes the sign bit (bit 7 of the result) to change state.
        ' 1 = Overflow occurred for signed arithmetic (in this arithmetic operation)
        ' 0 = No overflow occurred
    Symbol F_Z =    STATUS.2    ' Zero Bit
        ' 1 = The result of an arithmetic or logic operation is zero
        ' 0 = The result of an arithmetic or logic operation is not zero
    Symbol F_DC =   STATUS.1    ' Digit Carry/Borrow bit (ADDWF, ADDLW,SUBLW,SUBWF instructions)(1)
        ' 1 = A carry-out from the 4th low-order bit of the result occurred
        ' 0 = No carry-out from the 4th low-order bit of the result
    Symbol F_C =    STATUS.0    ' Carry/Borrow Bit (addwf, addlw, sublw, subwf instructions)(1)
        ' 1 = A carry-out from the Most Significant bit of the result occurred
        ' 0 = No carry-out from the Most Significant bit of the result occurred
' 
' Note 1: For Borrow, the polarity is reversed. A subtraction is executed by adding the twos complement of the
' second operand. For rotate (RRF, RLF) instructions, this bit is loaded with either the high-order or low-order
' bit of the source register.
'--------------------------------------------------------------------
'22/08/2012
'EECON1: DATA EEPROM CONTROL 1 REGISTER

    Symbol F_EEPGD = EECON1.7   ' FLASH Program or Data EEPROM Memory Select bit
        ' 1 = Access Flash program memory
        ' 0 = Access data EEPROM memory
    Symbol F_CFGS =  EECON1.6   ' FLASH Program/Data EEPROM or Configuration Select bit    
        ' 1 = Access Configuration registers
        ' 0 = Access Flash program or data EEPROM memory
    ' bit 5 Unimplemented: Read as 0
    Symbol F_FREE =  EECON1.4   ' FLASH Row (Block) Erase Enable bit 
        ' 1 = Erase the program memory block addressed by TBLPTR on the next WR command
        ' (cleared by completion of erase operation)
        ' 0 = Perform write-only
    Symbol F_WRERR = EECON1.3   ' Flash Program/Data EEPROM Error Flag Bit(1)    
        ' 1 = A write operation is prematurely terminated (any Reset during self-timed programming in normal
        ' operation, or an improper write attempt)
        ' 0 = The write operation completed
    Symbol F_WREN = EECON1.2    ' Flash Program/Data EEPROM Write Enable Bit    
        ' 1 = Allows write cycles to Flash program/data EEPROM
        ' 0 = Inhibits write cycles to Flash program/data EEPROM
    Symbol F_WR = EECON1.1      ' Write Control Bit      
        ' 1 = Initiates a data EEPROM erase/write cycle or a program memory erase cycle or write cycle.
        ' (The operation is self-timed and the bit is cleared by hardware once write is complete.
        ' The WR bit can only be set (not cleared) by software.)
        ' 0 = Write cycle to the EEPROM is complete
    Symbol F_RD = EECON1.0      ' Read Control Bit
        ' 1 = Initiates an EEPROM read (Read takes one cycle. RD is cleared by hardware. The RD bit can only
        ' be set (not cleared) by software. RD bit cannot be set when EEPGD = 1 or CFGS = 1.)
        ' 0 = Does not initiate an EEPROM read
'
' Note 1: When a WRERR occurs, the EEPGD and CFGS bits are not cleared. This allows tracing of the
' error condition.
'--------------------------------------------------------------------
'OPTION_REG Register, Bank1, Bank3	
'	Symbol F_RBPU = OPTION_REG.7	'port B enable bit
'	Symbol F_INTEDG = OPTION_REG.6	'interrupt edge bit
	'
'-------------------------------------------------------------------- 
'22/08/2012
' INTCON: INTERRUPT CONTROL REGISTER
    Symbol F_GIEH = INTCON.7        ' Enable all high priority interrupts
    Symbol F_GIE = INTCON.7         ' Global Interrupt Enable
    ' When IPEN = 0:
        ' 1 = Enables all unmasked interrupts
        ' 0 = Disables all interrupts including peripherals
        ' When IPEN = 1:
        ' 1 = Enables all high priority interrupts
        ' 0 = Disables all interrupts including low priority.
    Symbol F_GIEL =     INTCON.6    ' Low priority peripheral interrupt
    Symbol F_PEIE =     INTCON.6    ' Peripheral Interrupt Enable
        ' When IPEN = 0:
        ' 1 = Enables all unmasked peripheral interrupts
        ' 0 = Disables all peripheral interrupts
        ' When IPEN = 1:
        ' 1 = Enables all low priority interrupts
        ' 0 = Disables all low priority interrupts
    Symbol F_TMR0IE = INTCON.5      ' TMR0 Overflow Interrupt Enable
        ' 1 = Enables the TMR0 overflow interrupt
        ' 0 = Disables the TMR0 overflow interrupt
    Symbol F_INT0IE = INTCON.4      ' INT0 External Interrupt Enable
        ' 1 = Enables the INT0 external interrupt
        ' 0 = Disables the INT0 external interrupt
    Symbol F_RBIE = INTCON.3        'Port B Interrupt-On-Change (IOCx) Interrupt Enable Bit(2)
        '1 = Enables the IOCx port change Interrupt
        '0 = Disables the IOCx port change Interrupt
    Symbol F_TMR0IF = INTCON.2      ' TMR0 Overflow Interrupt Flag    
        ' 1 = TMR0 register has overflowed (must be cleared by software)
        ' 0 = TMR0 register did not overflow
    Symbol F_INT0IF = INTCON.1      ' INT0 External Interrupt Flag        
        ' 1 = The INT0 external interrupt occurred (must be cleared by software)
        ' 0 = The INT0 external interrupt did not occur
    Symbol F_RBIF = INTCON.0        'Port B Interrupt-On-Change (IOCx) Interrupt Flag Bit(1)
        '1 = At least one of the IOC<3:0> (RB<7:4>) pins changed state (must be cleared by software)
        '0 = None of the IOC<3:0> (RB<7:4>) pins have changed state
    '
'   Note 1: A mismatch condition will Continue To Set the RBIF Bit. Reading PORTB will End the
'           mismatch condition And allow the Bit To be cleared.
'        2: RB port change interrupts also require the individual pin IOCB enables.
'--------------------------------------------------------------------
'22/08/2012
'INTCON2: INTERRUPT CONTROL 2 REGISTER
    Symbol F_RBPU = INTCON2.7       'PORTB Pull-up Enable Bit
    Symbol F_NOT_RBPU = INTCON2.7       'PORTB Pull-up Enable Bit
        '1 = All PORTB pull-ups are disabled
        '0 = PORTB pull-ups are enabled provided that the pin is an input and the
        ' corresponding WPUB bit is set.
    Symbol F_INTEDG0 = INTCON2.6    'External Interrupt 0 Edge Select Bit
        '1 = Interrupt on rising edge
        '0 = Interrupt on falling edge
    Symbol F_INTEDG1 = INTCON2.5    'External Interrupt 1 Edge Select Bit
        '1 = Interrupt on rising edge
        '0 = Interrupt on falling edge
    Symbol F_INTEDG2 = INTCON2.4    'External Interrupt 2 Edge Select Bit
        '1 = Interrupt on rising edge
        '0 = Interrupt on falling edge
    'bit 3 Unimplemented: Read as 0
    Symbol F_TMR0IP = INTCON2.2     'TMR0 Overflow Interrupt Priority Bit
        '1 = High priority
        '0 = Low priority
    'bit 1 Unimplemented: Read as 0
    Symbol F_RBIP = INTCON2.0       'RB Port Change Interrupt Priority Bit
        '1 = High priority
        '0 = Low priority
'--------------------------------------------------------------------
'22/08/2012
'INTCON3: INTERRUPT CONTROL 3 REGISTER
    Symbol F_INT2IP = INTCON3.7     'INT2 External Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_INT1IP = INTCON3.6     'INT1 External Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    'bit 5 Unimplemented: Read as 0
    Symbol F_INT2IE = INTCON3.4     'INT2 External Interrupt Enable bit
        '1 = Enables the INT2 external interrupt
        '0 = Disables the INT2 external interrupt
    Symbol F_INT1IE = INTCON3.3     'INT1 External Interrupt Enable bit
        '1 = Enables the INT1 external interrupt
        '0 = Disables the INT1 external interrupt
    'bit 2 Unimplemented: Read as 0
    Symbol F_INT2IF = INTCON3.1     'INT2 External Interrupt Flag bit
        '1 = The INT2 external interrupt occurred (must be cleared by software)
        '0 = The INT2 external interrupt did not occur
    Symbol F_INT1IF = INTCON3.0     'INT1 External Interrupt Flag bit
        '1 = The INT1 external interrupt occurred (must be cleared by software)
        '0 = The INT1 external interrupt did not occur
'--------------------------------------------------------------------
'22/08/2012
'PIR1: PERIPHERAL INTERRUPT REQUEST (FLAG) REGISTER 1
    'Bit 7 Unimplemented: Read As 0.
    Symbol F_ADIF = PIR1.6      ' A/D Converter Interrupt Flag Bit
        ' 1 = An A/D conversion completed (must be cleared by software)
        ' 0 = The A/D conversion is Not complete Or has Not been started
    Symbol F_RCIF1 = PIR1.5     'EUSART1 Receive Interrupt Flag Bit
        '1 = The EUSART1 receive buffer, RCREG1, is full (cleared when RCREG1 is read)
        '0 = The EUSART1 receive buffer is empty
    Symbol F_TXIF = PIR1.4     'EUSART1 Transmit Interrupt Flag Bit
    Symbol F_TXIF1 = PIR1.4     'EUSART1 Transmit Interrupt Flag Bit
        '1 = The EUSART1 transmit buffer, TXREG1, is empty (cleared when TXREG1 is written)
        '0 = The EUSART1 transmit buffer is full
    Symbol F_SSP1IF = PIR1.3    ' Master Synchronous Serial Port 1 Interrupt Flag Bit
        ' 1 = The transmission/reception is complete (must be cleared by software)
        ' 0 = Waiting To transmit/receive
    Symbol F_CCP1IF = PIR1.2     ' CCP1 Interrupt Flag Bit
        ' Capture mode:
        ' 1 = A TMR1 register capture occurred (must be cleared by software)
        ' 0 = No TMR1 register capture occurred
        ' Compare mode:
        ' 1 = A TMR1 register compare match occurred (must be cleared by software)
        ' 0 = No TMR1 register compare match occurred
        ' PWM mode:
        ' Unused in this mode
    Symbol F_TMR2IF = PIR1.1     ' TMR2 to PR2 Match Interrupt Flag Bit
        ' 1 = TMR2 to PR2 match occurred (must be cleared by software)
        ' 0 = No TMR2 to PR2 match occurred
    Symbol F_TMR1IF = PIR1.0     ' TMR1 Overflow Interrupt Flag Bit
    ' 1 = TMR1 register overflowed (must be cleared by software)
    ' 0 = TMR1 register did Not overflow
'--------------------------------------------------------------------
'22/08/2012
'PIR2: PERIPHERAL INTERRUPT REQUEST (FLAG) REGISTER 2
    Symbol F_OSCFIF = PIR2.7    ' Oscillator Fail Interrupt Flag bit
    ' 1 = Device oscillator failed, clock input has changed to HFINTOSC (must be cleared by software)
    ' 0 = Device clock operating
    Symbol F_C1IF = PIR2.6      ' Comparator C1 Interrupt Flag bit
    ' 1 = Comparator C1 output has changed (must be cleared by software)
    ' 0 = Comparator C1 output has not changed
    Symbol F_C2IF = PIR2.5      ' Comparator C2 Interrupt Flag bit
    ' 1 = Comparator C2 output has changed (must be cleared by software)
    ' 0 = Comparator C2 output has not changed
    Symbol F_EEIF = PIR2.4      ' Data EEPROM/Flash Write Operation Interrupt Flag bit
    ' 1 = The write operation is complete (must be cleared by software)
    ' 0 = The write operation is not complete or has not been started
    Symbol F_BCLIF = PIR2.3     ' Bus Collision Interrupt Flag bit
    ' 1 = A bus collision occurred (must be cleared by software)
    ' 0 = No bus collision occurred
    Symbol F_HLVDIF = PIR2.2    ' Low-Voltage Detect Interrupt Flag bit
    ' 1 = A low-voltage condition occurred (direction determined by the VDIRMAG bit of the
    ' HLVDCON register)
    ' 0 = A low-voltage condition has not occurred
    Symbol F_TMR3IF = PIR2.1     ' TMR3 Overflow Interrupt Flag bit
    ' 1 = TMR3 register overflowed (must be cleared by software)
    ' 0 = TMR3 register did not overflow
    Symbol F_CCP2IF = PIR2.0     ' CCP2 Interrupt Flag bit
    ' Capture mode:
    ' 1 = A TMR1 register capture occurred (must be cleared by software)
    ' 0 = No TMR1 register capture occurred
    ' Compare mode:
    ' 1 = A TMR1 register compare match occurred (must be cleared by software)
    ' 0 = No TMR1 register compare match occurred
    ' PWM mode:
    ' Unused in this mode.
'-------------------------------------------------------------------------------
'22/08/2012
'PIR3: PERIPHERAL INTERRUPT (FLAG) REGISTER 3
    Symbol F_SSP2IF = PIR3.7        'Synchronous Serial Port Interrupt Flag bit
        '1 = The transmission/reception is complete (must be cleared in software)
        '0 = Waiting to transmit/receive
    Symbol F_BCL2IF = PIR3.6        'MSSP2 Bus Collision Interrupt Flag bit
        '1 = A bus collision has occurred while the SSP2 module configured in I2C master was transmitting
        '(must be cleared in software)
        '0 = No bus collision occurred
    Symbol F_RC2IF = PIR3.5         'EUSART2 Receive Interrupt Flag bit
        '1 = The EUSART2 receive buffer, RCREG2, is full (cleared by reading RCREG2)
        '0 = The EUSART2 receive buffer is empty
    Symbol F_TX2IF = PIR3.4         'EUSART2 Transmit Interrupt Flag bit
        '1 = The EUSART2 transmit buffer, TXREG2, is empty (cleared by writing TXREG2)
        '0 = The EUSART2 transmit buffer is full
    Symbol F_CTMUIF = PIR3.3        'CTMU Interrupt Flag bit
        '1 = CTMU interrupt occurred (must be cleared in software)
        '0 = No CTMU interrupt occurred
    Symbol F_TMR5GIF = PIR3.2       'TMR5 Gate Interrupt Flag bits
        '1 = TMR gate interrupt occurred (must be cleared in software)
        '0 = No TMR gate occurred
    Symbol F_TMR3GIF = PIR3.1       'TMR3 Gate Interrupt Flag bits
        '1 = TMR gate interrupt occurred (must be cleared in software)
        '0 = No TMR gate occurred
    Symbol F_TMR1GIF = PIR3.0       'TMR1 Gate Interrupt Flag bits
        '1 = TMR gate interrupt occurred (must be cleared in software)
        '0 = No TMR gate occurred
'-------------------------------------------------------------------------------
'22/08/2012
'PIR4: PERIPHERAL INTERRUPT (FLAG) REGISTER 4
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_CCP5IF = PIR4.2        'CCP5 Interrupt Flag bits
        'Capture mode:
            '1 = A TMR register capture occurred (must be cleared in software)
            '0 = No TMR register capture occurred
        'Compare mode:
            '1 = A TMR register compare match occurred (must be cleared in software)
            '0 = No TMR register compare match occurred
        'PWM mode:
            'Unused in PWM mode.
    Symbol F_CCP4IF = PIR4.1        'CCP4 Interrupt Flag bits
        'Capture mode:
            '1 = A TMR register capture occurred (must be cleared in software)
            '0 = No TMR register capture occurred
        'Compare mode:
            '1 = A TMR register compare match occurred (must be cleared in software)
            '0 = No TMR register compare match occurred
        'PWM mode:
            'Unused in PWM mode.
    Symbol F_CCP3IF = PIR4.0        'ECCP3 Interrupt Flag bits
        'Capture mode:
            '1 = A TMR register capture occurred (must be cleared in software)
            '0 = No TMR register capture occurred
        'Compare mode:
            '1 = A TMR register compare match occurred (must be cleared in software)
            '0 = No TMR register compare match occurred
        'PWM mode:
            'Unused in PWM mode.
'-------------------------------------------------------------------------------
'22/08/2012
'PIR5: PERIPHERAL INTERRUPT (FLAG) REGISTER 5
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_TMR6IF = PIR5.2        'TMR6 to PR6 Match Interrupt Flag bit
        '1 = TMR6 to PR6 match occurred (must be cleared in software)
        '0 = No TMR6 to PR6 match occurred
    Symbol F_TMR5IF = PIR5.1        'TMR5 Overflow Interrupt Flag bit
        '1 = TMR5 register overflowed (must be cleared in software)
        '0 = TMR5 register did not overflow
    Symbol F_TMR4IF = PIR5.0        'TMR4 to PR4 Match Interrupt Flag bit
        '1 = TMR4 to PR4 match occurred (must be cleared in software)
        '0 = No TMR4 to PR4 match occurred
'-------------------------------------------------------------------------------
'22/08/2012
'PIE1: PERIPHERAL INTERRUPT ENABLE (FLAG) REGISTER 1
'
    'bit 7 Unimplemented: Read as 0.
    Symbol F_ADIE = PIE1.6     ' A/D Converter Interrupt Enable bit
        ' 1 = Enables the A/D interrupt
        ' 0 = Disables the A/D interrupt
    Symbol F_R1CIE = PIE1.5      ' EUSART1 Receive Interrupt Enable Bit
        ' 1 = Enables the EUSART1 receive interrupt
        ' 0 = Disables the EUSART1 receive interrupt
    Symbol F_TX1IE = PIE1.4     ' EUSART1 Transmit Interrupt Enable bit
        ' 1 = Enables the EUSART1 transmit interrupt
        ' 0 = Disables the EUSART1 transmit interrupt
    Symbol F_SSP1IE = PIE1.3    ' Master Synchronous Serial Port 1 Interrupt Enable Bit
        ' 1 = Enables the MSSP1 interrupt
        ' 0 = Disables the MSSP1 interrupt
    Symbol F_CCP1IE = PIE1.2    ' CCP1 Interrupt Enable bit
        ' 1 = Enables the CCP1 interrupt
        ' 0 = Disables the CCP1 interrupt
    Symbol F_TMR2IE = PIE1.1    ' TMR2 to PR2 Match Interrupt Enable bit
        ' 1 = Enables the TMR2 to PR2 match interrupt
        ' 0 = Disables the TMR2 to PR2 match interrupt
    Symbol F_TMR1IE = PIE1.0    ' TMR1 Overflow Interrupt Enable bit
        ' 1 = Enables the TMR1 overflow interrupt
        ' 0 = Disables the TMR1 overflow interrupt
'--------------------------------------------------------------------
'22/08/2012
'PIE2: PERIPHERAL INTERRUPT ENABLE (FLAG) REGISTER 2
    Symbol F_OSCFIE = PIE2.7   ' Oscillator Fail Interrupt Enable bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_C1IE = PIE2.6     ' Comparator C1 Interrupt Enable bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_C2IE = PIE2.5     ' Comparator C2 Interrupt Enable bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_EEIE = PIE2.4     ' Data EEPROM/Flash Write Operation Interrupt Enable bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_BCLIE = PIE2.3    ' MSSP1 Bus Collision Interrupt Enable Bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_HLVDIE = PIE2.2   ' Low-Voltage Detect Interrupt Enable bit
    ' 1 = Enabled
    ' 0 = Disabled
    Symbol F_TMR3IE = PIE2.1   ' TMR3 Overflow Interrupt Enable bit
        ' 1 = Enabled
        ' 0 = Disabled
    Symbol F_CCP2IE = PIE2.0   ' CCP2 Interrupt Enable bit
    ' 1 = Enabled
    ' 0 = Disabled
'-------------------------------------------------------------------------------
'22/08/2012
'PIE3: PERIPHERAL INTERRUPT ENABLE (FLAG) REGISTER 3
    Symbol F_SSP2IE = PIE3.7    ' TMR5 Gate Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_BCL2IE = PIE3.6    ' Bus Collision Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_RC2IE = PIE3.5     ' EUSART2 Receive Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_TX2IE = PIE3.4     ' EUSART2 Transmit Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_CTMUIE = PIE3.3    ' CTMU Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_TMR5GIE = PIE3.2   ' TMR5 Gate Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_TMR3GIE = PIE3.1   ' TMR3 Gate Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_TMR1GIE = PIE3.0   ' TMR1 Gate Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
'-------------------------------------------------------------------------------
'22/08/2012
'PIE4: PERIPHERAL INTERRUPT ENABLE (FLAG) REGISTER 4
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_CCP5IE = PIE4.2    ' CCP5 Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_CCP4IE = PIE4.1    ' CCP4 Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
    Symbol F_CCP3IE = PIE4.0    ' CCP3 Interrupt Enable bit
        '1 = Enabled
        '0 = Disabled
'-------------------------------------------------------------------------------
'22/08/2012        
'PIE5: PERIPHERAL INTERRUPT ENABLE (FLAG) REGISTER 5
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_TMR6IE = PIE5.2    ' TMR6 to PR6 Match Interrupt Enable bit
        '1 = Enables the TMR6 to PR6 match interrupt
        '0 = Disables the TMR6 to PR6 match interrupt
    Symbol F_TMR5IE = PIE5.1    ' TMR5 Overflow Interrupt Enable bit
        '1 = Enables the TMR5 overflow interrupt
        '0 = Disables the TMR5 overflow interrupt
    Symbol F_TMR4IE = PIE5.0    ' TMR4 to PR4 Match Interrupt Enable bit
        '1 = Enables the TMR4 to PR4 match interrupt
        '0 = Disables the TMR4 to PR4 match interrupt
'-------------------------------------------------------------------------------
'22/08/2012
'IPR1: PERIPHERAL INTERRUPT PRIORITY REGISTER 1
    'bit 7 Unimplemented: Read as 0
    Symbol F_ADIP = IPR1.6     ' A/D Converter Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_RC1IP = IPR1.5    ' EUSART1 Receive Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_TX1IP = IPR1.4    ' EUSART1 Transmit Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_SSP1IP = IPR1.3   ' Master Synchronous Serial Port 1 Interrupt Priority Bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_CCP1IP = IPR1.2   ' CCP1 Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_TMR2IP = IPR1.1   ' TMR2 to PR2 Match Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_TMR1IP = IPR1.0   ' TMR1 Overflow Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
'--------------------------------------------------------------------
'22/08/2012
'IPR2: PERIPHERAL INTERRUPT PRIORITY REGISTER 2
    Symbol F_OSCFIP = IPR2.7       ' Oscillator Fail Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_C1IP = IPR2.6         ' Comparator C1 Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_C2IP = IPR2.5         ' Comparator C2 Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_EEIP = IPR2.4         ' Data EEPROM/Flash Write Operation Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_BCL1IP = IPR2.3       ' MSSP1 Bus Collision Interrupt Priority Bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_HLVDIP = IPR2.2       ' Low-Voltage Detect Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_TMR3IP = IPR2.1       ' TMR3 Overflow Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
    Symbol F_CCP2IP = IPR2.0       ' CCP2 Interrupt Priority bit
        ' 1 = High priority
        ' 0 = Low priority
'--------------------------------------------------------------------
'22/08/2012
'IPR3: PERIPHERAL INTERRUPT PRIORITY REGISTER 3
    Symbol F_SSP2IP = IPR3.7    ' Synchronous Serial Port 2 Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_BCL2IP = IPR3.6    ' Bus Collision 2 Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_RC2IP = IPR3.5     ' EUSART2 Receive Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TX2IP = IPR3.4     ' EUSART2 Transmit Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_CTMUIP = IPR3.3    ' CTMU Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TMR5GIP = IPR3.2   ' TMR5 Gate Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TMR3GIP = IPR3.1   ' TMR3 Gate Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TMR1GIP = IPR3.0   ' TMR1 Gate Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
'-------------------------------------------------------------------------------
'22/08/2012
'IPR4: PERIPHERAL INTERRUPT PRIORITY REGISTER 4
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_CCP5IP = IPR4.2    ' CCP5 Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_CCP4IP = IPR4.1    ' CCP4 Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_CCP3IP = IPR4.0    ' CCP3 Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
'-------------------------------------------------------------------------------
'22/08/2012
'IPR5: PERIPHERAL INTERRUPT PRIORITY REGISTER 5
    'bit 7-3 Unimplemented: Read as 0
    Symbol F_TMR6IP = IPR5.2    ' TMR6 to PR6 Match Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TMR5IP = IPR5.1    ' TMR5 Overflow Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
    Symbol F_TMR4IP = IPR5.0    ' TMR4 to PR4 Match Interrupt Priority bit
        '1 = High priority
        '0 = Low priority
'-------------------------------------------------------------------------------
'22/08/2012
' ANSELA  PORTA ANALOG SELECT REGISTER
    'bit 7-6 Unimplemented: Read as 0
    Symbol F_ANSA5 = ANSELA.5   ' RA5 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    'bit 4 Unimplemented: Read as 0
    'bit 3-0 ANSA<3:0>: RA<3:0> Analog Select bit
    Symbol F_ANSA3 = ANSELA.3   ' RA3 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSA2 = ANSELA.2   ' RA2 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSA1 = ANSELA.1   ' RA1 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSA0 = ANSELA.0   ' RA0 Analog Select bit    
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
'-------------------------------------------------------------------------------
'22/08/2012
'ANSELB  PORTB ANALOG SELECT REGISTER
    'bit 7-6 Unimplemented: Read as 0
    'bit 5-0 ANSB<5:0>: RB<5:0> Analog Select bit
    Symbol F_ANSB5 = ANSELB.5   ' RB5 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSB4 = ANSELB.4   ' RB4 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSB3 = ANSELB.3   ' RB3 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSB2 = ANSELB.2   ' RB2 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSB1 = ANSELB.1   ' RB1 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSB0 = ANSELB.0   ' RB5 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled                                        
'-------------------------------------------------------------------------------
'22/08/2012
'ANSELC  PORTC ANALOG SELECT REGISTER
    'bit 7-2 ANSC<7:2>: RC<7:2> Analog Select bit
    Symbol F_ANSC7 = ANSELC.7    ' RC7 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSC6 = ANSELC.6    ' RC6 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSC5 = ANSELC.5    ' RC5 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSC4 = ANSELC.4    ' RC4 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSC3 = ANSELC.3    ' RC3 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled 
    Symbol F_ANSC2 = ANSELC.2    ' RC2 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled               
    'bit 1-0 Unimplemented: Read as 0
'-------------------------------------------------------------------------------
'22/08/2012
$if _device = _18F43K22 Or _device = _18F44K22 Or _device = _18F45K22 Or _device = _18F46K22
'ANSELD  PORTD ANALOG SELECT REGISTER
    'bit 7-0 ANSD<7:0>: RD<7:0> Analog Select bit
    Symbol F_ANSD7 = ANSELD.7   ' RD7 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSD6 = ANSELD.6   ' RD6 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSD5 = ANSELD.5   ' RD5 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSD4 = ANSELD.4   ' RD4 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled        
    Symbol F_ANSD3 = ANSELD.3   ' RD3 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled        
    Symbol F_ANSD2 = ANSELD.2   ' RD2 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSD1 = ANSELD.1   ' RD1 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled        
    Symbol F_ANSD0 = ANSELD.0  ' RD0 Analog Select bit
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled 
$endif       
'-------------------------------------------------------------------------------
'22/08/2012
'ANSELE  PORTE ANALOG SELECT REGISTER
    'bit 7-3 Unimplemented: Read as 0
    'bit 2-0 ANSE<2:0>: RE<2:0> Analog Select bit(1)
$if _device = _18F43K22 Or _device = _18F44K22 Or _device = _18F45K22 Or _device = _18F46K22
    Symbol F_ANSE2 = ANSELE.2   ' RE2 Analog Select bit(1)
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSE1 = ANSELE.1   ' RE1 Analog Select bit(1)
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled
    Symbol F_ANSE0 = ANSELE.0   ' RE0 Analog Select bit(1)
        '1 = Digital input buffer disabled
        '0 = Digital input buffer enabled        
$endif
'                
'Note 1: Available on PIC18(L)F4XK22 devices only.
'-------------------------------------------------------------------------------
'22/08/2012
'TRISx: PORTx TRI-STATE REGISTER(1)
    'bit 7-0 TRISx<7:0>: PORTx Tri-State Control bit
        '1 = PORTx pin configured as an input (tri-stated)
        '0 = PORTx pin configured as an output
'
'Note 1: Register description for TRISA, TRISB, TRISC and TRISD.
'-------------------------------------------------------------------------------
'22/08/2012
$if _device = _18F43K22 Or _device = _18F44K22 Or _device = _18F45K22 Or _device = _18F46K22
'TRISE: PORTE TRI-STATE REGISTER
    Symbol F_WPUE3 = TRISE.7    ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    'bit 6-3 Unimplemented: Read as 0
'
    Symbol F_TRISE2 = TRISE.2   'PORTE2 Tri-State Control Bit(1)
        '1 = PORTE pin configured as an input (tri-stated)
        '0 = PORTE pin configured as an output
    Symbol F_TRISE1 = TRISE.1   'PORTE1 Tri-State Control Bit(1)
        '1 = PORTE pin configured as an input (tri-stated)
        '0 = PORTE pin configured as an output        
    Symbol F_TRISE0 = TRISE.0   'PORTE0 Tri-State Control Bit(1)
        '1 = PORTE pin configured as an input (tri-stated)
        '0 = PORTE pin configured as an output
$endif
'
'Note 1: Available on PIC18(L)F4XK22 devices only.
'-------------------------------------------------------------------------------
'22/08/2012
'WPUB: WEAK PULL-UP PORTB REGISTER
    Symbol F_WPUB7 = WPUB.7 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB6 = WPUB.6 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB5 = WPUB.5 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB4 = WPUB.4 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB3 = WPUB.3 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB2 = WPUB.2 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB1 = WPUB.1 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
    Symbol F_WPUB0 = WPUB.0 ' Weak Pull-up Register bits
        '1 = Pull-up enabled on PORT pin
        '0 = Pull-up disabled on PORT pin
'-------------------------------------------------------------------------------
'22/08/2012
'IOCB: INTERRUPT-ON-CHANGE PORTB CONTROL REGISTER
    Symbol F_IOCB7 = IOCB.7     ' PORTB7 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
    Symbol F_IOCB6 = IOCB.6     ' PORTB6 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
    Symbol F_IOCB5 = IOCB.5     ' PORTB5 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
    Symbol F_IOCB4 = IOCB.4     ' PORTB4 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
    Symbol F_IOCB3 = IOCB.3     ' PORTB3 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
    Symbol F_IOCB2 = IOCB.2     ' PORTB2 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled                
    Symbol F_IOCB1 = IOCB.1     ' PORTB1 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled 
    Symbol F_IOCB0 = IOCB.0     ' PORTB0 Interrupt-on-Change PORTB control bits
        '1 = Interrupt-on-change enabled(1)
        '0 = Interrupt-on-change disabled
'                       
'Note 1: Interrupt-on-change requires that the F_RBIE bit (INTCON<3>) is set.
'-------------------------------------------------------------------------------
'22/08/2012
'SLRCON: SLEW RATE CONTROL REGISTER
    ' bit 7-5 Unimplemented: Read as 0
$if _device = _18F43K22 Or _device = _18F44K22 Or _device = _18F45K22 Or _device = _18F46K22
    Symbol F_SLRE = SLRCON.4    ' PORTE Slew Rate Control bit(1)
        ' 1 = All outputs on PORTE slew at a limited rate
        ' 0 = All outputs on PORTE slew at the standard rate
    Symbol F_SLRD = SLRCON.3    ' PORTD Slew Rate Control bit(1)
        ' 1 = All outputs on PORTD slew at a limited rate
        ' 0 = All outputs on PORTD slew at the standard rate
    Symbol F_SLRC = SLRCON.2    ' PORTC Slew Rate Control bit
        ' 1 = All outputs on PORTC slew at a limited rate
        ' 0 = All outputs on PORTC slew at the standard rate
$endif        
    Symbol F_SLRB = SLRCON.1    ' PORTB Slew Rate Control bit
    ' 1 = All outputs on PORTB slew at a limited rate
    ' 0 = All outputs on PORTB slew at the standard rate
    Symbol F_SLRA = SLRCON.0    ' PORTA Slew Rate Control bit
    ' 1 = All outputs on PORTA slew at a limited rate(2)
    ' 0 = All outputs on PORTA slew at the standard rate
'
' Note 1: These bits are not implemented on PIC18F2XK20 devices.
'      2: The slew rate of RA6 defaults to standard rate when the pin is used as CLKOUT.
'-------------------------------------------------------------------------------
'22/08/2012
'T0CON: TIMER0 CONTROL REGISTER
    Symbol F_TMR0ON = T0CON.7   ' Timer0 On/Off Control Bit
        '1 = Enables Timer0
        '0 = Stops Timer0
    Symbol F_T08BIT = T0CON.6   ' Timer0 8-bit/16-bit Control bit
        '1 = Timer0 is configured as an 8-bit timer/counter
        '0 = Timer0 is configured as a 16-bit timer/counter
    Symbol F_T0CS = T0CON.5     ' Timer0 Clock Source Select bit
        '1 = Transition on T0CKI pin
        '0 = Internal instruction cycle clock (CLKOUT)
    Symbol F_T0SE = T0CON.4     ' Timer0 Source Edge Select bit
        '1 = Increment on high-to-low transition on T0CKI pin
        '0 = Increment on low-to-high transition on T0CKI pin
    Symbol F_PSA = T0CON.3      ' Timer0 Prescaler Assignment bit
        '1 = TImer0 prescaler is NOT assigned. Timer0 clock input bypasses prescaler.
        '0 = Timer0 prescaler is assigned. Timer0 clock input comes from prescaler output.
    'bit 2-0 T0PS<2:0>: Timer0 Prescaler Select bits
        '111 = 1:256 prescale value
        '110 = 1:128 prescale value
        '101 = 1:64 prescale value
        '100 = 1:32 prescale value
        '011 = 1:16 prescale value
        '010 = 1:8 prescale value
        '001 = 1:4 prescale value
        '000 = 1:2 prescale value
'-------------------------------------------------------------------------------
'22/08/2012
'T1CON: TIMER1 CONTROL REGISTER
    Symbol F_TMR1CS1 = T1CON.7      ' Timer1 Clock Source Select bits
    Symbol F_TMR1CS0 = T1CON.6      ' Timer1 Clock Source Select bits
        '11 =Reserved. Do not use.
        '10 =Timer1 clock source is pin or oscillator:
        'If T1SOSCEN = 0:
            'External clock from T1CKI pin (on the rising edge)
        'If T1SOSCEN = 1:
            'Crystal oscillator on SOSCI/SOSCO pins
            '01 =Timer1 clock source is system clock (FOSC)
            '00 =Timer1 clock source is instruction clock (FOSC/4)
    Symbol F_T1CKPS1 = T1CON.5       ' Timer1 Input Clock Prescale Select bits
    Symbol F_T1CKPS0 = T1CON.4       ' Timer1 Input Clock Prescale Select bits
        '11 = 1:8 Prescale value
        '10 = 1:4 Prescale value
        '01 = 1:2 Prescale value
        '00 = 1:1 Prescale value
    Symbol F_T1SOSCEN = T1CON.3     ' Secondary Oscillator Enable Control Bit
        '1 = Dedicated Secondary oscillator circuit enabled
        '0 = Dedicated Secondary oscillator circuit disabled
    Symbol F_T1SYNC = T1CON.2       ' Timer1 External Clock Input Synchronization Control bi
        'TMR1CS<1:0> = 1X
            '1 = Do not synchronize external clock input
            '0 = Synchronize external clock input with system clock (FOSC)
        'TMR1CS<1:0> = 0X
            'This bit is ignored. Timer1 uses the internal clock when TMR1CS<1:0> = 1X.
    Symbol F_T1RD16 = T1CON.1       ' 16-Bit Read/Write Mode Enable Bit
        '1 = Enables register read/write of Timer1 in one 16-bit operation
        '0 = Enables register read/write of Timer1 in two 8-bit operation
    Symbol F_TMR1ON = T1CON.0       ' Timer1 On bit
        '1 = Enables Timer1
        '0 = Stops Timer1
        'Clears Timer1 Gate flip-flop
'-------------------------------------------------------------------------------
'22/08/2012
'T3CON: TIMER3 CONTROL REGISTER
    Symbol F_TMR3CS1 = T3CON.7      ' Timer3 Clock Source Select bits
    Symbol F_TMR3CS0 = T3CON.6      ' Timer3 Clock Source Select bits
        '11 =Reserved. Do not use.
        '10 =Timer3 clock source is pin or oscillator:
        'If T3SOSCEN = 0:
            'External clock from T3CKI pin (on the rising edge)
        'If T3SOSCEN = 1:
            'Crystal oscillator on SOSCI/SOSCO pins
            '01 =Timer3 clock source is system clock (FOSC)
            '00 =Timer3 clock source is instruction clock (FOSC/4)
    Symbol F_T3CKPS1 = T3CON.5       ' Timer3 Input Clock Prescale Select bits
    Symbol F_T3CKPS0 = T3CON.4       ' Timer3 Input Clock Prescale Select bits
        '11 = 1:8 Prescale value
        '10 = 1:4 Prescale value
        '01 = 1:2 Prescale value
        '00 = 1:1 Prescale value
    Symbol F_T3SOSCEN = T3CON.3     ' Secondary Oscillator Enable Control Bit
        '1 = Dedicated Secondary oscillator circuit enabled
        '0 = Dedicated Secondary oscillator circuit disabled
    Symbol F_T3SYNC = T3CON.2       ' Timer3 External Clock Input Synchronization Control bi
        'TMR3CS<1:0> = 1X
            '1 = Do not synchronize external clock input
            '0 = Synchronize external clock input with system clock (FOSC)
        'TMR3CS<1:0> = 0X
            'This bit is ignored. Timer1 uses the internal clock when TMRxCS<1:0> = 1X.
    Symbol F_T3RD16 = T3CON.1       ' 16-Bit Read/Write Mode Enable Bit
        '1 = Enables register read/write of Timer1 in one 16-bit operation
        '0 = Enables register read/write of Timer1 in two 8-bit operation
    Symbol F_TMR3ON = T3CON.0       ' Timer3 On bit
        '1 = Enables Timer3
        '0 = Stops Timer3
        'Clears Timer3 Gate flip-flop
'-------------------------------------------------------------------------------
'22/08/2012
'T5CON: TIMER1 CONTROL REGISTER
    Symbol F_TMR5CS1 = T5CON.7      ' Timer5 Clock Source Select bits
    Symbol F_TMR5CS0 = T5CON.6      ' Timer5 Clock Source Select bits
        '11 =Reserved. Do not use.
        '10 =Timer5 clock source is pin or oscillator:
        'If T5SOSCEN = 0:
            'External clock from T5CKI pin (on the rising edge)
        'If T5SOSCEN = 1:
            'Crystal oscillator on SOSCI/SOSCO pins
            '01 =Timer5 clock source is system clock (FOSC)
            '00 =Timer5 clock source is instruction clock (FOSC/4)
    Symbol F_T5CKPS1 = T5CON.5       ' Timer3 Input Clock Prescale Select bits
    Symbol F_T5CKPS0 = T5CON.4       ' Timer3 Input Clock Prescale Select bits
        '11 = 1:8 Prescale value
        '10 = 1:4 Prescale value
        '01 = 1:2 Prescale value
        '00 = 1:1 Prescale value
    Symbol F_T5SOSCEN = T5CON.3     ' Secondary Oscillator Enable Control Bit
        '1 = Dedicated Secondary oscillator circuit enabled
        '0 = Dedicated Secondary oscillator circuit disabled
    Symbol F_T5SYNC = T5CON.2       ' Timer5 External Clock Input Synchronization Control bi
        'TMR5CS<1:0> = 1X
            '1 = Do not synchronize external clock input
            '0 = Synchronize external clock input with system clock (FOSC)
        'TMR5CS<1:0> = 0X
            'This bit is ignored. Timer1 uses the internal clock when TMR5CS<1:0> = 1X.
    Symbol F_T5RD16 = T5CON.1       ' 16-Bit Read/Write Mode Enable Bit
        '1 = Enables register read/write of Timer5 in one 16-bit operation
        '0 = Enables register read/write of Timer5 in two 8-bit operation
    Symbol F_TMR5ON = T5CON.0       ' Timer5 On bit
        '1 = Enables Timer5
        '0 = Stops Timer5
        'Clears Timer5 Gate flip-flop
'-------------------------------------------------------------------------------
'22/08/2012
'T1GCON: TIMER1/3/5 GATE CONTROL REGISTER
    Symbol F_TMR1GE = T1GCON.7      ' Timer1 Gate Enable Bit
        'If TMRxON = 0:
            'This Bit is ignored
        'If TMRxON = 1:
            '1 = Timer1 counting is controlled by the Timer1/3/5 gate function
            '0 = Timer1 counts regardless of Timer1 gate function
    Symbol F_T1GPOL = T1GCON.6      ' Timer1 Gate Polarity Bit
        '1 = Timer1 gate is active-high (Timer1 counts when gate is High)
        '0 = Timer1 gate is active-low (Timer1 counts when gate is Low)
    Symbol F_T1GTM = T1GCON.5       ' Timer1 Gate Toggle Mode Bit
        '1 = Timer1 Gate Toggle mode is enabled
        '0 = Timer1 Gate Toggle mode is disabled And Toggle flip-flop is cleared
        'Timer1 gate flip-flop toggles On every rising edge.
    Symbol F_T1GSPM = T1GCON.4      ' Timer1 Gate Single-Pulse Mode Bit
        '1 = Timer1 gate Single-Pulse mode is enabled And is controlling Timer1 gate
        '0 = Timer1 gate Single-Pulse mode is disabled
'    Symbol F_T1GGO/DONE = TXGCON.3  ' Timer1/3/5 Gate Single-Pulse Acquisition STATUS Bit
    Symbol F_T1GGO_NotDONE = T1GCON.3  ' Timer1 Gate Single-Pulse Acquisition STATUS Bit
        '1 = Timer1 gate single-pulse acquisition is ready, waiting For an edge
        '0 = Timer1 gate single-pulse acquisition has completed Or has Not been started
        'This Bit is automatically cleared when T1GSPM is cleared.
    Symbol F_T1GVAL = T1GCON.2      ' Timer1 Gate Current State Bit
        'Indicates the current state of the Timer1 gate that could be provided To TMR1H:TMR1L.
        'Unaffected by Timer1 Gate Enable (TMR1GE).
    Symbol F_T1GSS1 = T1GCON.1      '1X Timer1 Gate Source Select bits
    Symbol F_T1GSS0 = T1GCON.0      'X0 Timer1 Gate Source Select bits
        '00 = Timer1 Gate pin
        '01 = Timer2 Match PR2 Output (See Table 12-6 For proper timer match selection)
        '10 = Comparator 1 optionally synchronized Output (SYNCC1OUT)
        '11 = Comparator 2 optionally synchronized Output (SYNCC2OUT)
'-------------------------------------------------------------------------------
'22/08/2012
'T3GCON: TIMER1/3/5 GATE CONTROL REGISTER
    Symbol F_TMR3GE = T3GCON.7      ' Timer3 Gate Enable Bit
        'If TMRxON = 0:
            'This Bit is ignored
        'If TMR3ON = 1:
            '1 = Timer1/3/5 counting is controlled by the Timer1/3/5 gate function
            '0 = Timer1/3/5 counts regardless of Timer1/3/5 gate function
    Symbol F_T3GPOL = T3GCON.6      ' Timer3 Gate Polarity Bit
        '1 = Timer3 gate is active-high (Timer3 counts when gate is High)
        '0 = Timer3 gate is active-low (Timer3 counts when gate is Low)
    Symbol F_T3GTM = T3GCON.5       ' Timer3 Gate Toggle Mode Bit
        '1 = Timer3 Gate Toggle mode is enabled
        '0 = Timer3 Gate Toggle mode is disabled And Toggle flip-flop is cleared
        'Timer3 gate flip-flop toggles On every rising edge.
    Symbol F_T3GSPM = T3GCON.4      ' Timer3 Gate Single-Pulse Mode Bit
        '1 = Timer3 gate Single-Pulse mode is enabled And is controlling Timer3 gate
        '0 = Timer3 gate Single-Pulse mode is disabled
'    Symbol F_T3GGO/DONE = T3GCON.3  ' Timer3 Gate Single-Pulse Acquisition STATUS Bit
    Symbol F_T3GGO_NotDONE = T3GCON.3  ' Timer3 Gate Single-Pulse Acquisition STATUS Bit
        '1 = Timer3 gate single-pulse acquisition is ready, waiting For an edge
        '0 = Timer3 gate single-pulse acquisition has completed Or has Not been started
        'This Bit is automatically cleared when T3GSPM is cleared.
    Symbol F_T3GVAL = T3GCON.2      ' Timer3 Gate Current State Bit
        'Indicates the current state of the Timer3 gate that could be provided To TMR3H:TMR3L.
        'Unaffected by Timer3 Gate Enable (TMR3GE).
    Symbol F_T3GSS1 = T3GCON.1      '1X Timer3 Gate Source Select bits
    Symbol F_T3GSS0 = T3GCON.0      'X0 Timer3 Gate Source Select bits
        '00 = Timer3 Gate pin
        '01 = Timer4 Match PR4 Output (See Table 12-6 For proper timer match selection)
        '10 = Comparator 1 optionally synchronized Output (SYNCC1OUT)
        '11 = Comparator 2 optionally synchronized Output (SYNCC2OUT)
'-------------------------------------------------------------------------------
'22/08/2012
'T5GCON: TIMER5 GATE CONTROL REGISTER
    Symbol F_TMR5GE = T5GCON.7      ' Timer5 Gate Enable Bit
        'If TMR5ON = 0:
            'This Bit is ignored
        'If TMR5ON = 1:
            '1 = Timer5 counting is controlled by the Timer5 gate function
            '0 = Timer5 counts regardless of Timer5 gate function
    Symbol F_T5GPOL = T5GCON.6      ' Timer5 Gate Polarity Bit
        '1 = Timer5 gate is active-high (Timer5 counts when gate is High)
        '0 = Timer5 gate is active-low (Timer5 counts when gate is Low)
    Symbol F_T5GTM = T5GCON.5       ' Timer5 Gate Toggle Mode Bit
        '1 = Timer5 Gate Toggle mode is enabled
        '0 = Timer5 Gate Toggle mode is disabled And Toggle flip-flop is cleared
        'Timer5 gate flip-flop toggles On every rising edge.
    Symbol F_T5GSPM = T5GCON.4      ' Timer5 Gate Single-Pulse Mode Bit
        '1 = Timer5 gate Single-Pulse mode is enabled And is controlling Timer5 gate
        '0 = Timer5 gate Single-Pulse mode is disabled
'    Symbol F_T5GGO/DONE = T5GCON.3  ' Timer5 Gate Single-Pulse Acquisition STATUS Bit
    Symbol F_T5GGO_NotDONE = T5GCON.3  ' Timer5 Gate Single-Pulse Acquisition STATUS Bit
        '1 = Timer5 gate single-pulse acquisition is ready, waiting For an edge
        '0 = Timer5 gate single-pulse acquisition has completed Or has Not been started
        'This Bit is automatically cleared when T5GSPM is cleared.
    Symbol F_T5GVAL = T5GCON.2      ' Timer5 Gate Current State Bit
        'Indicates the current state of the Timer5 gate that could be provided To TMR5H:TMR5L.
        'Unaffected by Timer5 Gate Enable (TMR5GE).
    Symbol F_T5GSS1 = T5GCON.1      '1X Timer5 Gate Source Select bits
    Symbol F_T5GSS0 = T5GCON.0      'X0 Timer5 Gate Source Select bits
        '00 = Timer5 Gate pin
        '01 = Timer6 Match PR6 Output (See Table 12-6 For proper timer match selection)
        '10 = Comparator 1 optionally synchronized Output (SYNCC1OUT)
        '11 = Comparator 2 optionally synchronized Output (SYNCC2OUT)
'-------------------------------------------------------------------------------
'22/08/2012
'T2CON: TIMER2 CONTROL REGISTER
    'bit 7 Unimplemented: Read as 0
    'bit 6-3 T2OUTPS<3:0>: Timer2 Output Postscaler Select bits
        '0000 = 1:1 Postscaler
        '0001 = 1:2 Postscaler
        '0010 = 1:3 Postscaler
        '0011 = 1:4 Postscaler
        '0100 = 1:5 Postscaler
        '0101 = 1:6 Postscaler
        '0110 = 1:7 Postscaler
        '0111 = 1:8 Postscaler
        '1000 = 1:9 Postscaler
        '1001 = 1:10 Postscaler
        '1010 = 1:11 Postscaler
        '1011 = 1:12 Postscaler
        '1100 = 1:13 Postscaler
        '1101 = 1:14 Postscaler
        '1110 = 1:15 Postscaler
        '1111 = 1:16 Postscaler
    Symbol F_TMR2ON = T2CON.2       ' Timer2 On Bit    
        '1 = Timer2 is on
        '0 = Timer2 is off
    Symbol F_T2CKPS1  = T2CON.1     '<1>: Timer2-type Clock Prescale Select bits
    Symbol F_T2CKPS0  = T2CON.0     '<0>: Timer2-type Clock Prescale Select bits
        '00 = Prescaler is 1
        '01 = Prescaler is 4
        '1x = Prescaler is 16
'-------------------------------------------------------------------------------
'22/08/2012
'T4CON: TIMER4 CONTROL REGISTER
    'bit 7 Unimplemented: Read as 0
    'bit 6-3 T4OUTPS<3:0>: Timer4 Output Postscaler Select bits
        '0000 = 1:1 Postscaler
        '0001 = 1:2 Postscaler
        '0010 = 1:3 Postscaler
        '0011 = 1:4 Postscaler
        '0100 = 1:5 Postscaler
        '0101 = 1:6 Postscaler
        '0110 = 1:7 Postscaler
        '0111 = 1:8 Postscaler
        '1000 = 1:9 Postscaler
        '1001 = 1:10 Postscaler
        '1010 = 1:11 Postscaler
        '1011 = 1:12 Postscaler
        '1100 = 1:13 Postscaler
        '1101 = 1:14 Postscaler
        '1110 = 1:15 Postscaler
        '1111 = 1:16 Postscaler
    Symbol F_TMR4ON = T4CON.2       ' Timer4 On Bit    
        '1 = Timer4 is on
        '0 = Timer4 is off
    Symbol F_T4CKPS1  = T4CON.1     '<1>: Timer4-type Clock Prescale Select bits
    Symbol F_T4CKPS0  = T4CON.0     '<0>: Timer4-type Clock Prescale Select bits
        '00 = Prescaler is 1
        '01 = Prescaler is 4
        '1x = Prescaler is 16
'-------------------------------------------------------------------------------
'22/08/2012
'T6CON: TIMER6 CONTROL REGISTER
    'bit 7 Unimplemented: Read as 0
    'bit 6-3 T6OUTPS<3:0>: Timer6 Output Postscaler Select bits
        '0000 = 1:1 Postscaler
        '0001 = 1:2 Postscaler
        '0010 = 1:3 Postscaler
        '0011 = 1:4 Postscaler
        '0100 = 1:5 Postscaler
        '0101 = 1:6 Postscaler
        '0110 = 1:7 Postscaler
        '0111 = 1:8 Postscaler
        '1000 = 1:9 Postscaler
        '1001 = 1:10 Postscaler
        '1010 = 1:11 Postscaler
        '1011 = 1:12 Postscaler
        '1100 = 1:13 Postscaler
        '1101 = 1:14 Postscaler
        '1110 = 1:15 Postscaler
        '1111 = 1:16 Postscaler
    Symbol F_TMR6ON = T6CON.2       ' Timer6 On Bit    
        '1 = Timer6 is on
        '0 = Timer6 is off
    Symbol F_T6CKPS1  = T6CON.1     '<1>: Timer6-type Clock Prescale Select bits
    Symbol F_T6CKPS0  = T6CON.0     '<0>: Timer6-type Clock Prescale Select bits
        '00 = Prescaler is 1
        '01 = Prescaler is 4
        '1x = Prescaler is 16
'-------------------------------------------------------------------------------
'22/08/2012
'CCP1CON: STANDARD CCP1 CONTROL REGISTER
    'bit 7-6 Unused
    'bit 5-4 DC1B<1:0>: PWM Duty Cycle Least Significant bits
        'Capture mode:
            'Unused
        'Compare mode:
            'Unused
        'PWM mode:
            'These bits are the two LSbs of the PWM duty cycle.
            'The eight MSbs are found in CCPRxL.
    'bit 3-0 CCP1M<3:0>: ECCP1 Mode Select bits
        '0000 = Capture/Compare/PWM off (resets the module)
        '0001 = Reserved
        '0010 = Compare mode: toggle output on match
        '0011 = Reserved
        '0100 = Capture mode: every falling edge
        '0101 = Capture mode: every rising edge
        '0110 = Capture mode: every 4th rising edge
        '0111 = Capture mode: every 16th rising edge
        '1000 = Compare mode: set output on compare match (CCP1 pin is set, CCP1IF is set)
        '1001 = Compare mode: clear output on compare match (CCP1 pin is cleared, CCP1IF is set)
        '1010 = Compare mode: generate software interrupt on compare match
        '       (CCP1 pin is unaffected, CCP1IF is set)
        '1011 = Compare mode: Special Event Trigger (CCP1 pin is unaffected, CCP1IF is set)
            'TimerX (selected by CXTSEL bits) is reset
            'ADON is set, starting A/D conversion if A/D module is enabled(1)
        '11xx =: PWM mode
'
'Note 1: This feature is available on CCP5 only.
'-------------------------------------------------------------------------------  
'22/08/2012
'CCP2CON: STANDARD CCP2 CONTROL REGISTER
    'bit 7-6 Unused
    'bit 5-4 DC2B<1:0>: PWM Duty Cycle Least Significant bits
        'Capture mode:
            'Unused
        'Compare mode:
            'Unused
        'PWM mode:
            'These bits are the two LSbs of the PWM duty cycle.
            'The eight MSbs are found in CCPR2L.
    'bit 3-0 CCP2M<3:0>: ECCP2 Mode Select bits
        '0000 = Capture/Compare/PWM off (resets the module)
        '0001 = Reserved
        '0010 = Compare mode: toggle output on match
        '0011 = Reserved
        '0100 = Capture mode: every falling edge
        '0101 = Capture mode: every rising edge
        '0110 = Capture mode: every 4th rising edge
        '0111 = Capture mode: every 16th rising edge
        '1000 = Compare mode: set output on compare match (CCP2 pin is set, CCP2IF is set)
        '1001 = Compare mode: clear output on compare match (CCP2 pin is cleared, CCPxIF is set)
        '1010 = Compare mode: generate software interrupt on compare match
        '       (CCP2 pin is unaffected, CCP2IF is set)
        '1011 = Compare mode: Special Event Trigger (CCP2 pin is unaffected, CCP2IF is set)
            'TimerX (selected by CxTSEL bits) is reset
            'ADON is set, starting A/D conversion if A/D module is enabled(1)
        '11xx =: PWM mode
'
'Note 1: This feature is available on CCP5 only.
'------------------------------------------------------------------------------- 
'22/08/2012
'CCP3CON: STANDARD CCP3 CONTROL REGISTER
    'bit 7-6 Unused
    'bit 5-4 DC3B<1:0>: PWM Duty Cycle Least Significant bits
        'Capture mode:
            'Unused
        'Compare mode:
            'Unused
        'PWM mode:
            'These bits are the two LSbs of the PWM duty cycle.
            'The eight MSbs are found in CCPR3L.
    'bit 3-0 CCP3M<3:0>: ECCP3 Mode Select bits
        '0000 = Capture/Compare/PWM off (resets the module)
        '0001 = Reserved
        '0010 = Compare mode: toggle output on match
        '0011 = Reserved
        '0100 = Capture mode: every falling edge
        '0101 = Capture mode: every rising edge
        '0110 = Capture mode: every 4th rising edge
        '0111 = Capture mode: every 16th rising edge
        '1000 = Compare mode: set output on compare match (CCP3 pin is set, CCP3IF is set)
        '1001 = Compare mode: clear output on compare match (CCP3 pin is cleared, CCP3IF is set)
        '1010 = Compare mode: generate software interrupt on compare match
        '       (CCP3 pin is unaffected, CCP3IF is set)
        '1011 = Compare mode: Special Event Trigger (CCP3 pin is unaffected, CCP3IF is set)
            'TimerX (selected by CxTSEL bits) is reset
            'ADON is set, starting A/D conversion if A/D module is enabled(1)
        '11xx =: PWM mode
'
'Note 1: This feature is available on CCP5 only.
'------------------------------------------------------------------------------- 
'22/08/2012
'CCPxCON: ENHANCED CCPx CONTROL REGISTER
    'bit 7-6 PxM<1:0>: Enhanced PWM Output Configuration bits
        'If CCPxM<3:2> = 00, 01, 10: (Capture/Compare modes)
            'xx = PxA assigned as Capture/Compare input; PxB, PxC, PxD assigned as port pins
            'Half-Bridge ECCP Modules(1):
        'If CCPxM<3:2> = 11: (PWM modes)
            '0x = Single output; PxA modulated; PxB assigned as port pin
            '1x = Half-Bridge output; PxA, PxB modulated with dead-band control
        'Full-Bridge ECCP Modules(1):
        'If CCPxM<3:2> = 11: (PWM modes)
            '00 = Single output; PxA modulated; PxB, PxC, PxD assigned as port pins
            '01 = Full-Bridge output forward; PxD modulated; PxA active; PxB, PxC inactive
            '10 = Half-Bridge output; PxA, PxB modulated with dead-band control;
            '       PxC, PxD assigned as port pins
            '11 = Full-Bridge output reverse; PxB modulated; PxC active; PxA, PxD inactive
    'bit 5-4 DCxB<1:0>: PWM Duty Cycle Least Significant bits
        'Capture mode:
            'Unused
        'Compare mode:
            'Unused
        'PWM mode:
            'These bits are the two LSbs of the PWM duty cycle.
            'The eight MSbs are found in CCPRxL.
'
'Note 1: See Table 14-1 to determine Full-Bridge and Half-Bridge ECCPs for the device being used.
'
'CCPxCON: ENHANCED CCPx CONTROL REGISTER (CONTINUED)
    'bit 3-0 CCPxM<3:0>: ECCPx Mode Select bits
        '0000 = Capture/Compare/PWM off (resets the module)
        '0001 = Reserved
        '0010 = Compare mode: toggle output on match
        '0011 = Reserved
        '0100 = Capture mode: every falling edge
        '0101 = Capture mode: every rising edge
        '0110 = Capture mode: every 4th rising edge
        '0111 = Capture mode: every 16th rising edge
        '1000 = Compare mode: set output on compare match (CCPx pin is set, CCPxIF is set)
        '1001 = Compare mode: clear output on compare match (CCPx pin is cleared, CCPxIF is set)
        '1010 = Compare mode: generate software interrupt on compare match (CCPx pin is unaffected,
        '       CCPxIF is set)
        '1011 = Compare mode: Special Event Trigger (CCPx pin is unaffected, CCPxIF is set)
        '       TimerX is reset
        'Half-Bridge ECCP Modules(1):
            '1100 = PWM mode: PxA active-high; PxB active-high
            '1101 = PWM mode: PxA active-high; PxB active-low
            '1110 = PWM mode: PxA active-low; PxB active-high
            '1111 = PWM mode: PxA active-low; PxB active-low
        'Full-Bridge ECCP Modules(1):
            '1100 = PWM mode: PxA, PxC active-high; PxB, PxD active-high
            '1101 = PWM mode: PxA, PxC active-high; PxB, PxD active-low
            '1110 = PWM mode: PxA, PxC active-low; PxB, PxD active-high
            '1111 = PWM mode: PxA, PxC active-low; PxB, PxD active-low
'REGISTER 14-2: CCPxCON: ENHANCED CCPx CONTROL REGISTER (CONTINUED)
'Note 1: See Table 14-1 to determine Full-Bridge and Half-Bridge ECCPs for the device being used.
'-------------------------------------------------------------------------------
'22/08/2012
'CCPTMRS0: PWM TIMER SELECTION CONTROL REGISTER 0
    Symbol F_C3TSEL1 = CCPTMRS0.7   '<1>: CCP3 Timer Selection bits
    Symbol F_C3TSEL0 = CCPTMRS0.6   '<0>: CCP3 Timer Selection bits
        '00 = CCP3  Capture/Compare modes use Timer1, PWM modes use Timer2
        '01 = CCP3  Capture/Compare modes use Timer3, PWM modes use Timer4
        '10 = CCP3  Capture/Compare modes use Timer5, PWM modes use Timer6
        '11 = Reserved
    'bit 5 Unused
    Symbol F_C2TSEL1 = CCPTMRS0.4   '<1>: CCP2 Timer Selection bits
    Symbol F_C2TSEL0 = CCPTMRS0.3   '<0>: CCP2 Timer Selection bits
        '00 = CCP2  Capture/Compare modes use Timer1, PWM modes use Timer2
        '01 = CCP2  Capture/Compare modes use Timer3, PWM modes use Timer4
        '10 = CCP2  Capture/Compare modes use Timer5, PWM modes use Timer6
        '11 = Reserved
    'bit 2 Unused
    Symbol F_C1TSEL1 = CCPTMRS0.1   '<1>: CCP1 Timer Selection bits
    Symbol F_C1TSEL0 = CCPTMRS0.0   '<1>: CCP1 Timer Selection bits
        '00 = CCP1  Capture/Compare modes use Timer1, PWM modes use Timer2
        '01 = CCP1  Capture/Compare modes use Timer3, PWM modes use Timer4
        '10 = CCP1  Capture/Compare modes use Timer5, PWM modes use Timer6
        '11 = Reserved
'-------------------------------------------------------------------------------
'22/08/2012
'CCPTMRS1: PWM TIMER SELECTION CONTROL REGISTER 1
    'bit 7-4 Unimplemented: Read as 0
    Symbol F_C5TSEL1 = CCPTMRS1.3   '<1>: CCP5 Timer Selection bits
    Symbol F_C5TSEL0 = CCPTMRS1.2   '<0>: CCP5 Timer Selection bits
        '00 = CCP5  Capture/Compare modes use Timer1, PWM modes use Timer2
        '01 = CCP5  Capture/Compare modes use Timer3, PWM modes use Timer4
        '10 = CCP5  Capture/Compare modes use Timer5, PWM modes use Timer6
        '11 = Reserved
    Symbol F_C4TSEL1 = CCPTMRS1.1    '<1:0>: CCP4 Timer Selection bits
    Symbol F_C4TSEL0 = CCPTMRS1.0    '<1:0>: CCP4 Timer Selection bits
        '00 = CCP4  Capture/Compare modes use Timer1, PWM modes use Timer2
        '01 = CCP4  Capture/Compare modes use Timer3, PWM modes use Timer4
        '10 = CCP4  Capture/Compare modes use Timer5, PWM modes use Timer6
        '11 = Reserved
'-------------------------------------------------------------------------------
'22/08/2012
'ECCP1AS: CCP1 AUTO-SHUTDOWN CONTROL REGISTER
    Symbol F_CCP1ASE = ECCP1AS.7        ' CCP1 Auto-shutdown Event Status bit
        'if P1RSEN = 1;
            '1 = An Auto-shutdown event occurred; CCP1ASE bit will automatically
            '    clear when event goes away; CCPx outputs in shutdown state
            '0 = CCP1 outputs are operating
        'if P1RSEN = 0;
            '1 = An Auto-shutdown event occurred; bit must be cleared in software
            '    to restart PWM; CCP1 outputs in shutdown state
            '0 = CCPx outputs are operating
    Symbol F_CCP1AS2 = ECCP1AS.6    ' <2>: CCP1 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP1AS1 = ECCP1AS.5    ' <1>: CCP1 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP1AS0 = ECCP1AS.4    ' <0>: CCP1 Auto-Shutdown Source Select bits (1)    
        '000 = Auto-shutdown is disabled
        '001 = Comparator C1  output high will cause shutdown event
        '010 = Comparator C2  output high will cause shutdown event
        '011 = Either Comparator C1 or C2  output high will cause shutdown event
        '100 = FLT0 pin - low level will cause shutdown event
        '101 = FLT0 pin or Comparator C1  low level will cause shutdown event
        '110 = FLT0 pin or Comparator C2  low level will cause shutdown event
        '111 = FLT0 pin or Comparators C1 or C2  low level will cause shutdown event
    Symbol F_PSS1AC1 = ECCP1AS.3    '<1>: Pins P1A and P1C Shutdown State Control bits
    Symbol F_PSS1AC0 = ECCP1AS.2    '<0>: Pins P1A and P1C Shutdown State Control bits
        '00 = Drive pins P1A and P1C to 0
        '01 = Drive pins P1A and P1C to 1
        '1x = Pins P1A and P1C tri-state
    Symbol F_PSS1BD1 = ECCP1AS.1    '<1:0>: Pins P1B And P1D Shutdown State Control bits
    Symbol F_PSS1BD0 = ECCP1AS.0    '<1:0>: Pins P1B And P1D Shutdown State Control bits
        '00 = Drive pins P1B and P1D to 0
        '01 = Drive pins P1B and P1D to 1
        '1x = Pins P1B and P1D tri-state
'
'Note 1: If C1SYNC or C2SYNC bits in the CM2CON1 register are enabled,
' the shutdown will be delayed by Timer1.
'-------------------------------------------------------------------------------
'22/08/2012
'ECCP2AS: CCP2 AUTO-SHUTDOWN CONTROL REGISTER
    Symbol F_CCP2ASE = ECCP2AS.7        ' CCP2 Auto-shutdown Event Status bit
        'if P2RSEN = 1;
            '1 = An Auto-shutdown event occurred; CCP2ASE bit will automatically
            '    clear when event goes away; CCPx outputs in shutdown state
            '0 = CCPx outputs are operating
        'if P2RSEN = 0;
            '1 = An Auto-shutdown event occurred; bit must be cleared in software
            '    to restart PWM; CCPx outputs in shutdown state
            '0 = CCP2 outputs are operating
    Symbol F_CCP2AS2 = ECCP2AS.6    ' <2>: CCP2 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP2AS1 = ECCP2AS.5    ' <1>: CCP2 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP2AS0 = ECCP2AS.4    ' <0>: CCP2 Auto-Shutdown Source Select bits (1)    
        '000 = Auto-shutdown is disabled
        '001 = Comparator C1  output high will cause shutdown event
        '010 = Comparator C2  output high will cause shutdown event
        '011 = Either Comparator C1 or C2  output high will cause shutdown event
        '100 = FLT0 pin - low level will cause shutdown event
        '101 = FLT0 pin or Comparator C1  low level will cause shutdown event
        '110 = FLT0 pin or Comparator C2  low level will cause shutdown event
        '111 = FLT0 pin or Comparators C1 or C2  low level will cause shutdown event
    Symbol F_PSS2AC1 = ECCP2AS.3    '<1>: Pins P2A and PxC Shutdown State Control bits
    Symbol F_PSS2AC0 = ECCP2AS.2    '<0>: Pins P2A and PxC Shutdown State Control bits
        '00 = Drive pins P2A and P2C to 0
        '01 = Drive pins P2A and P2C to 1
        '1x = Pins PxA and PxC tri-state
    Symbol F_PSS2BD1 = ECCP2AS.1    '<1>: Pins PxB And PxD Shutdown State Control bits
    Symbol F_PSS2BD0 = ECCP2AS.0    '<0>: Pins PxB And PxD Shutdown State Control bits
        '00 = Drive pins P2B and P2D to 0
        '01 = Drive pins P2B and P2D to 1
        '1x = Pins P2B and P2D tri-state
'
'Note 1: If C1SYNC or C2SYNC bits in the CM2CON1 register are enabled,
' the shutdown will be delayed by Timer1.
'-------------------------------------------------------------------------------
'22/08/2012
'ECCP3AS: CCPX AUTO-SHUTDOWN CONTROL REGISTER
    Symbol F_CCP3ASE = ECCP3AS.7        ' CCP3 Auto-shutdown Event Status bit
        'if P3RSEN = 1;
            '1 = An Auto-shutdown event occurred; CCP3ASE bit will automatically
            '    clear when event goes away; CCP3 outputs in shutdown state
            '0 = CCPx outputs are operating
        'if P3RSEN = 0;
            '1 = An Auto-shutdown event occurred; bit must be cleared in software
            '    to restart PWM; CCPx outputs in shutdown state
            '0 = CCP3 outputs are operating
    Symbol F_CCP3AS2 = ECCP3AS.6    ' <2>: CCP3 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP3AS1 = ECCP3AS.5    ' <1>: CCP3 Auto-Shutdown Source Select bits (1)
    Symbol F_CCP3AS0 = ECCP3AS.4    ' <0>: CCP3 Auto-Shutdown Source Select bits (1)    
        '000 = Auto-shutdown is disabled
        '001 = Comparator C1  output high will cause shutdown event
        '010 = Comparator C2  output high will cause shutdown event
        '011 = Either Comparator C1 or C2  output high will cause shutdown event
        '100 = FLT0 pin - low level will cause shutdown event
        '101 = FLT0 pin or Comparator C1  low level will cause shutdown event
        '110 = FLT0 pin or Comparator C2  low level will cause shutdown event
        '111 = FLT0 pin or Comparators C1 or C2  low level will cause shutdown event
    Symbol F_PSS3AC1 = ECCP3AS.3    '<1>: Pins P3A and PxC Shutdown State Control bits
    Symbol F_PSS3AC0 = ECCP3AS.2    '<0>: Pins P3A and PxC Shutdown State Control bits
        '00 = Drive pins P3A and P3C to 0
        '01 = Drive pins P3A and P3C to 1
        '1x = Pins P3A and P3C tri-state
    Symbol F_PSS3BD1 = ECCP3AS.1    '<1>: Pins P3B And P3D Shutdown State Control bits
    Symbol F_PSS3BD0 = ECCP3AS.0    '<0>: Pins P3B And P3D Shutdown State Control bits
        '00 = Drive pins P3B and P3D to 0
        '01 = Drive pins P3B and P3D to 1
        '1x = Pins P3B and P3D tri-state
'
'Note 1: If C1SYNC or C2SYNC bits in the CM2CON1 register are enabled,
' the shutdown will be delayed by Timer1.
'-------------------------------------------------------------------------------
'22/08/2012
'PWM1CON: ENHANCED PWM CONTROL REGISTER
    Symbol F_P1RSEN = PWM1CON.7     ' PWM Restart Enable Bit
        '1 = Upon auto-shutdown, the CCP1ASE bit clears automatically once the 
        '   shutdown event goes away; the PWM restarts automatically
        '0 = Upon auto-shutdown, CCPxASE must be cleared in software to restart the PWM
    'bit 6-0 P1DC<6:0>: PWM Delay Count bits
        'PxDCx = Number of FOSC/4 (4 * TOSC) cycles between the scheduled time
        'when a PWM signal should transition active and the actual time it transitions active
'-------------------------------------------------------------------------------
'22/08/2012
'PWM2CON: ENHANCED PWM CONTROL REGISTER
    Symbol F_P2RSEN = PWM2CON.7     ' PWM Restart Enable Bit
        '1 = Upon auto-shutdown, the CCP2ASE bit clears automatically once the 
        '   shutdown event goes away; the PWM restarts automatically
        '0 = Upon auto-shutdown, CCPxASE must be cleared in software to restart the PWM
    'bit 6-0 P2DC<6:0>: PWM Delay Count bits
        'P2DCx = Number of FOSC/4 (4 * TOSC) cycles between the scheduled time
        'when a PWM signal should transition active and the actual time it transitions active
'-------------------------------------------------------------------------------
'22/08/2012
'PWM3CON: ENHANCED PWM CONTROL REGISTER
    Symbol F_P3RSEN = PWM3CON.7     ' PWM Restart Enable Bit
        '1 = Upon auto-shutdown, the CCPxASE bit clears automatically once the 
        '   shutdown event goes away; the PWM restarts automatically
        '0 = Upon auto-shutdown, CCPxASE must be cleared in software to restart the PWM
    'bit 6-0 P3DC<6:0>: PWM Delay Count bits
        'P3DCx = Number of FOSC/4 (4 * TOSC) cycles between the scheduled time
        'when a PWM signal should transition active and the actual time it transitions active
'-------------------------------------------------------------------------------
'22/08/2012
'PSTR1CON: PWM STEERING CONTROL REGISTER(1)
    'bit 7-5 Unimplemented: Read as 0
    Symbol F_STR1SYNC = PSTR1CON.4  ' Steering Sync Bit    
        '1 = Output steering update occurs on next PWM period
        '0 = Output steering update occurs at the beginning of the instruction cycle boundary
    Symbol F_STR1D = PSTR1CON.3     ' Steering Enable Bit D
        '1 = P1D pin has the PWM waveform with polarity control from CCP1M<1:0>
        '0 = P1D pin is assigned to port pin
    Symbol F_STR1C = PSTR1CON.2     ' Steering Enable Bit C
        '1 = P1C pin has the PWM waveform with polarity control from CCP1M<1:0>
        '0 = P1C pin is assigned to port pin
    Symbol F_STR1B = PSTR1CON.1     ' Steering Enable Bit B
        '1 = P1B pin has the PWM waveform with polarity control from CCP1M<1:0>
        '0 = P1B pin is assigned to port pin
    Symbol F_STR1A = PSTR1CON.0     ' Steering Enable bit A
        '1 = P1A pin has the PWM waveform with polarity control from CCP1xM<1:0>
        '0 = P1A pin is assigned to port pin
'
'Note 1: The PWM Steering mode is available only when the CCPxCON register bits
'        CCPxM<3:2> = 11 and PxM<1:0> = 00.
'-------------------------------------------------------------------------------
'22/08/2012
'PSTR2CON: PWM STEERING CONTROL REGISTER(1)
    'bit 7-5 Unimplemented: Read as 0
    Symbol F_STR2SYNC = PSTR2CON.4  ' Steering Sync Bit    
        '1 = Output steering update occurs on next PWM period
        '0 = Output steering update occurs at the beginning of the instruction cycle boundary
    Symbol F_STR2D = PSTR2CON.3     ' Steering Enable Bit D
        '1 = P2D pin has the PWM waveform with polarity control from CCP2M<1:0>
        '0 = P2D pin is assigned to port pin
    Symbol F_STR2C = PSTR2CON.2     ' Steering Enable Bit C
        '1 = P2C pin has the PWM waveform with polarity control from CCP2M<1:0>
        '0 = P2C pin is assigned to port pin
    Symbol F_STR2B = PSTR2CON.1     ' Steering Enable Bit B
        '1 = P2B pin has the PWM waveform with polarity control from CCP2M<1:0>
        '0 = P2B pin is assigned to port pin
    Symbol F_STR2A = PSTR2CON.0     ' Steering Enable bit A
        '1 = P2A pin has the PWM waveform with polarity control from CCP2M<1:0>
        '0 = P2A pin is assigned to port pin
'
'Note 1: The PWM Steering mode is available only when the CCPxCON register bits
'        CCPxM<3:2> = 11 and PxM<1:0> = 00.
'-------------------------------------------------------------------------------
'22/08/2012
'PSTR3CON: PWM STEERING CONTROL REGISTER(1)
    'bit 7-5 Unimplemented: Read as 0
    Symbol F_STR3SYNC = PSTR3CON.4  ' Steering Sync Bit    
        '1 = Output steering update occurs on next PWM period
        '0 = Output steering update occurs at the beginning of the instruction cycle boundary
    Symbol F_STR3D = PSTR3CON.3     ' Steering Enable Bit D
        '1 = P3D pin has the PWM waveform with polarity control from CCP3M<1:0>
        '0 = P3D pin is assigned to port pin
    Symbol F_STR3C = PSTR3CON.2     ' Steering Enable Bit C
        '1 = P3C pin has the PWM waveform with polarity control from CCP3M<1:0>
        '0 = P3C pin is assigned to port pin
    Symbol F_STR3B = PSTR3CON.1     ' Steering Enable Bit B
        '1 = P3B pin has the PWM waveform with polarity control from CCP3M<1:0>
        '0 = P3B pin is assigned to port pin
    Symbol F_STR3A = PSTR3CON.0     ' Steering Enable bit A
        '1 = P3A pin has the PWM waveform with polarity control from CCP3M<1:0>
        '0 = P3A pin is assigned to port pin
'
'Note 1: The PWM Steering mode is available only when the CCPxCON register bits
'        CCPxM<3:2> = 11 and PxM<1:0> = 00.
'-------------------------------------------------------------------------------
'22/08/2012
'SSP1STAT: SSP1 STATUS REGISTER
    Symbol F_SMP1 = SSP1STAT.7       ' SPI Data Input Sample bit
    'SPI Master mode:
        '1 = Input data sampled at end of data output time
        '0 = Input data sampled at middle of data output time
    'SPI Slave mode:
        'SMP must be cleared when SPI is used in Slave mode
        'In I2 C Master or Slave mode:
        '1 = Slew rate control disabled for standard speed mode (100 kHz and 1 MHz)
        '0 = Slew rate control enabled for high speed mode (400 kHz)
    Symbol F_CKE1 = SSP1STAT.6       ' SPI Clock Edge Select bit (SPI mode only)
        'In SPI Master or Slave mode:
            '1 = Transmit occurs on transition from active to Idle clock state
            '0 = Transmit occurs on transition from Idle to active clock state
        'In I2 C mode only:
            '1 = Enable input logic so that thresholds are compliant with SMbus specification
            '0 = Disable SMbus specific inputs
    'bit 5 D/A: Data/Address bit (I2C mode only)
    Symbol F_D_Not_A1 = SSP1STAT.5   ' Data/Address bit (I2C mode only)    
    Symbol F_D_A1 = SSP1STAT.5       ' Data/Address bit (I2C mode only)
        '1 = Indicates that the last byte received or transmitted was data
        '0 = Indicates that the last byte received or transmitted was address
    Symbol F_P1 = SSP1STAT.4         ' Stop bit
        '(I2C mode only. This bit is cleared when the MSSPx module is disabled, SSPxEN is cleared.)
        '1 = Indicates that a Stop bit has been detected last (this bit is 0 on Reset)
        '0 = Stop bit was not detected last
    Symbol F_S1 = SSP1STAT.3         ' Start bit
        '(I2C mode only. This bit is cleared when the MSSPx module is disabled, SSPxEN is cleared.)
        '1 = Indicates that a Start bit has been detected last (this bit is 0 on Reset)
        '0 = Start bit was not detected last
    'bit 2 R/W: Read/Write bit information (I2C mode only)
    Symbol F_R_Not_W1 = SSP1STAT.2   ' Read/Write bit information (I2C mode only)
    Symbol F_R_W1 = SSP1STAT.2       ' Read/Write bit information (I2C mode only)
        'This bit holds the R/W bit information following the last address match. This bit is only valid from the address match
        'to the next Start bit, Stop bit, or not ACK bit.
        'In I2 C Slave mode:
            '1 = Read
            '0 = Write
        'In I2 C Master mode:
            '1 = Transmit is in progress
            '0 = Transmit is not in progress
        'OR-ing this bit with SEN, RSEN, PEN, RCEN or ACKEN will indicate if the MSSPx is in Idle mode.
    Symbol F_UA1 = SSP1STAT.1        ' Update Address bit (10-bit I2C mode only)
        '1 = Indicates that the user needs to update the address in the SSPxADD register
        '0 = Address does not need to be updated
    Symbol F_BF1 = SSP1STAT.0        ' Buffer Full Status bit
        'Receive (SPI and I2 C modes):
            '1 = Receive complete, SSPxBUF is full
            '0 = Receive not complete, SSPxBUF is empty
        'Transmit (I2 C mode only):
            '1 = Data transmit in progress (does not include the ACK and Stop bits), SSPxBUF is full
            '0 = Data transmit complete (does not include the ACK and Stop bits), SSPxBUF is empty
'--------------------------------------------------------------------
'22/08/2012
'SSP2STAT: SSPx STATUS REGISTER
    Symbol F_SMP2 = SSP2STAT.7       ' SPI Data Input Sample bit
    'SPI Master mode:
        '1 = Input data sampled at end of data output time
        '0 = Input data sampled at middle of data output time
    'SPI Slave mode:
        'SMP must be cleared when SPI is used in Slave mode
        'In I2 C Master or Slave mode:
        '1 = Slew rate control disabled for standard speed mode (100 kHz and 1 MHz)
        '0 = Slew rate control enabled for high speed mode (400 kHz)
    Symbol F_CKE2 = SSP2STAT.6       ' SPI Clock Edge Select bit (SPI mode only)
        'In SPI Master or Slave mode:
            '1 = Transmit occurs on transition from active to Idle clock state
            '0 = Transmit occurs on transition from Idle to active clock state
        'In I2 C mode only:
            '1 = Enable input logic so that thresholds are compliant with SMbus specification
            '0 = Disable SMbus specific inputs
    'bit 5 D/A: Data/Address bit (I2C mode only)
    Symbol F_D_Not_A2 = SSP2STAT.5   ' Data/Address bit (I2C mode only)    
    Symbol F_D_A2 = SSP2STAT.5       ' Data/Address bit (I2C mode only)
        '1 = Indicates that the last byte received or transmitted was data
        '0 = Indicates that the last byte received or transmitted was address
    Symbol F_P2 = SSP2STAT.4         ' Stop bit
        '(I2C mode only. This bit is cleared when the MSSPx module is disabled, SSPxEN is cleared.)
        '1 = Indicates that a Stop bit has been detected last (this bit is 0 on Reset)
        '0 = Stop bit was not detected last
    Symbol F_S2 = SSP2STAT.3         ' Start bit
        '(I2C mode only. This bit is cleared when the MSSPx module is disabled, SSPxEN is cleared.)
        '1 = Indicates that a Start bit has been detected last (this bit is 0 on Reset)
        '0 = Start bit was not detected last
    'bit 2 R/W: Read/Write bit information (I2C mode only)
    Symbol F_R_Not_W2 = SSP2STAT.2   ' Read/Write bit information (I2C mode only)
    Symbol F_R_W2 = SSP2STAT.2       ' Read/Write bit information (I2C mode only)
        'This bit holds the R/W bit information following the last address match. This bit is only valid from the address match
        'to the next Start bit, Stop bit, or not ACK bit.
        'In I2 C Slave mode:
            '1 = Read
            '0 = Write
        'In I2 C Master mode:
            '1 = Transmit is in progress
            '0 = Transmit is not in progress
        'OR-ing this bit with SEN, RSEN, PEN, RCEN or ACKEN will indicate if the MSSPx is in Idle mode.
    Symbol F_UA2 = SSP2STAT.1        ' Update Address bit (10-bit I2C mode only)
        '1 = Indicates that the user needs to update the address in the SSPxADD register
        '0 = Address does not need to be updated
    Symbol F_BF2 = SSP2STAT.0        ' Buffer Full Status bit
        'Receive (SPI and I2 C modes):
            '1 = Receive complete, SSPxBUF is full
            '0 = Receive not complete, SSPxBUF is empty
        'Transmit (I2 C mode only):
            '1 = Data transmit in progress (does not include the ACK and Stop bits), SSPxBUF is full
            '0 = Data transmit complete (does not include the ACK and Stop bits), SSPxBUF is empty
'-------------------------------------------------------------------------------
'22/08/2012
'SSP1CON1: SSP1 CONTROL REGISTER 1
    Symbol F_WCOL1 = SSP1CON1.7      ' Write Collision Detect bit
        'Master mode:
            '1 = A write to the SSPxBUF register was attempted while the I2C
            '    conditions were not valid for a transmission to be started
            '0 = No collision
        'Slave mode:
            '1 = The SSPxBUF register is written while it is still transmitting the previous word (must be cleared in software)
            '0 = No collision
    Symbol F_SSP1OV = SSP1CON1.6        ' Receive Overflow Indicator bit(1)
        'In SPI mode:
            '1 = A new byte is received while the SSPxBUF register is still holding the previous data. In case of overflow, the data
            'in SSPxSR is lost. Overflow can only occur in Slave mode. In Slave mode, the user must read the SSPxBUF, even
        'if only transmitting data, to avoid setting overflow. In Master mode, the overflow bit is not set since each new reception
            '(and transmission) is initiated by writing to the SSPxBUF register (must be cleared in software).
            '0 = No overflow
        'In I2 C mode:
            '1 = A byte is received while the SSPxBUF register is still holding the previous byte. SSPxOV is a dont care in
            '    Transmit mode (must be cleared in software).
            '0 = No overflow
    Symbol F_SSP1EN = SSP1CON1.5        ' Synchronous Serial Port Enable bit
        'In both modes, when enabled, these pins must be properly configured as input or output
        'In SPI mode:
            '1 = Enables serial port and configures SCKx, SDOx, SDIx and SSx as the source of the serial port pins(2)
            '0 = Disables serial port and configures these pins as I/O port pins
        'In I2 C mode:
            '1 = Enables the serial port and configures the SDAx and SCLx pins as the source of the serial port pins(3)
            '0 = Disables serial port and configures these pins as I/O port pins
    Symbol F_CKP1 = SSP1CON1.4       ' Clock Polarity Select bit
        'In SPI mode:
            '1 = Idle state for clock is a high level
            '0 = Idle state for clock is a low level
        'In I2 C Slave mode:
            'SCLx release control
            '1 = Enable clock
            '0 = Holds clock low (clock stretch). (Used to ensure data setup time.)
        'In I2 C Master mode:
            'Unused in this mode
'-------------------------------------------------------------------------------
'22/08/2012
'SSP2CON1: SSP2 CONTROL REGISTER 1
    Symbol F_WCOL2 = SSP2CON1.7      ' Write Collision Detect bit
        'Master mode:
            '1 = A write to the SSPxBUF register was attempted while the I2C
            '    conditions were not valid for a transmission to be started
            '0 = No collision
        'Slave mode:
            '1 = The SSPxBUF register is written while it is still transmitting the previous word (must be cleared in software)
            '0 = No collision
    Symbol F_SSP2OV = SSP2CON1.6        ' Receive Overflow Indicator bit(1)
        'In SPI mode:
            '1 = A new byte is received while the SSPxBUF register is still holding the previous data. In case of overflow, the data
            'in SSPxSR is lost. Overflow can only occur in Slave mode. In Slave mode, the user must read the SSPxBUF, even
        'if only transmitting data, to avoid setting overflow. In Master mode, the overflow bit is not set since each new reception
            '(and transmission) is initiated by writing to the SSPxBUF register (must be cleared in software).
            '0 = No overflow
        'In I2 C mode:
            '1 = A byte is received while the SSPxBUF register is still holding the previous byte. SSPxOV is a dont care in
            '    Transmit mode (must be cleared in software).
            '0 = No overflow
    Symbol F_SSP2EN = SSP2CON1.5        ' Synchronous Serial Port Enable bit
        'In both modes, when enabled, these pins must be properly configured as input or output
        'In SPI mode:
            '1 = Enables serial port and configures SCKx, SDOx, SDIx and SSx as the source of the serial port pins(2)
            '0 = Disables serial port and configures these pins as I/O port pins
        'In I2 C mode:
            '1 = Enables the serial port and configures the SDAx and SCLx pins as the source of the serial port pins(3)
            '0 = Disables serial port and configures these pins as I/O port pins
    Symbol F_CKP2 = SSP2CON1.4       ' Clock Polarity Select bit
        'In SPI mode:
            '1 = Idle state for clock is a high level
            '0 = Idle state for clock is a low level
        'In I2 C Slave mode:
            'SCLx release control
            '1 = Enable clock
            '0 = Holds clock low (clock stretch). (Used to ensure data setup time.)
        'In I2 C Master mode:
            'Unused in this mode
'SSPxCON1: SSPx CONTROL REGISTER 1 (CONTINUED)

    'bit 3-0 SSPxM<3:0>: Synchronous Serial Port Mode Select bits
        '0000 = SPI Master mode, clock = FOSC/4
        '0001 = SPI Master mode, clock = FOSC/16
        '0010 = SPI Master mode, clock = FOSC/64
        '0011 = SPI Master mode, clock = TMR2 output/2
        '0100 = SPI Slave mode, clock = SCKx pin, SSx pin control enabled
        '0101 = SPI Slave mode, clock = SCKx pin, SSx pin control disabled, SSx can be used as I/O pin
        '0110 = I2C Slave mode, 7-bit address
        '0111 = I2C Slave mode, 10-bit address
        '1000 = I2C Master mode, clock = FOSC / (4 * (SSPxADD+1))(4)
        '1001 = Reserved
        '1010 = SPI Master mode, clock = FOSC/(4 * (SSPxADD+1))
        '1011 = I2C firmware controlled Master mode (slave idle)
        '1100 = Reserved
        '1101 = Reserved
        '1110 = I2C Slave mode, 7-bit address with Start and Stop bit interrupts enabled
        '1111 = I2C Slave mode, 10-bit address with Start and Stop bit interrupts enabled
'
'Note 1: In Master mode, the overflow bit is not set since each new reception
'        (and transmission) is initiated by writing to the SSPxBUF register.
'     2: When enabled, these pins must be properly configured as input or output.
'     3: When enabled, the SDAx and SCLx pins must be configured as inputs.
'     4: SSPxADD values of 0, 1 or 2 are not supported for I2C Mode.
'-------------------------------------------------------------------------------
'22/08/2012
$ifdef __SSP1CON2 
'SSP1CON2: SSP1 CONTROL REGISTER 2
    Symbol F_GCEN1 = SSP1CON2.7      ' General Call Enable bit (in I2C Slave mode only)
        '1 = Enable interrupt when a general call address (0x00 or 00h) is received in the SSPxSR
        '0 = General call address disabled
    Symbol F_ ACKSTAT1 = SSP1CON2.6  ' Acknowledge Status bit (in I2C mode only)
        '1 = Acknowledge was not received
        '0 = Acknowledge was received
    Symbol F_ACKDT1 = SSP1CON2.5     ' Acknowledge Data bit (in I2C mode only)
        'In Receive mode:
            'Value transmitted when the user initiates an Acknowledge sequence at the end of a receive
            '1 = Not Acknowledge
            '0 = Acknowledge
    Symbol F_ACKEN1 = SSP1CON2.4     '(1): Acknowledge Sequence Enable bit (in I2C Master mode only)
        'In Master Receive mode:
            '1 = Initiate Acknowledge sequence on SDAx and SCLx pins, and transmit ACKDT data bit.
            'Automatically cleared by hardware.
            '0 = Acknowledge sequence idle
    Symbol F_RCEN1 = SSP1CON2.3      '(1): Receive Enable bit (in I2C Master mode only)
        '1 = Enables Receive mode for I2C
        '0 = Receive idle
    Symbol F_PEN1 = SSP1CON2.2       '(1)Stop Condition Enable bit (in I2C Master mode only)
        'SCKx Release Control:
        '1 = Initiate Stop condition on SDAx and SCLx pins. Automatically cleared by hardware.
        '0 = Stop condition Idle
    Symbol F_RSEN1 = SSP1CON2.1      '(1): Repeated Start Condition Enabled bit (in I2C Master mode only)
        '1 = Initiate Repeated Start condition on SDAx and SCLx pins. Automatically cleared by hardware.
        '0 = Repeated Start condition Idle
    Symbol F_SEN1 = SSP1CON2.0       '(1): Start Condition Enabled bit (in I2C Master mode only)
        'In Master mode:
            '1 = Initiate Start condition on SDAx and SCLx pins. Automatically cleared by hardware.
            '0 = Start condition Idle
        'In Slave mode:
            '1 = Clock stretching is enabled for both slave transmit and slave receive (stretch enabled)
            '0 = Clock stretching is disabled
'
'Note 1: For bits ACKEN, RCEN, PEN, RSEN, SEN: If the I2C module is not in the Idle mode,
'        this bit may not be set (no spooling) and the SSPxBUF may not be written
'       (or writes to the SSPxBUF are disabled).
$endif
'-------------------------------------------------------------------------------
'22/08/2012
$ifdef _SSP2CON2
'SSP2CON2: SSP2 CONTROL REGISTER 2
    Symbol F_GCEN2 = SSP2CON2.7      ' General Call Enable bit (in I2C Slave mode only)
        '1 = Enable interrupt when a general call address (0x00 or 00h) is received in the SSPxSR
        '0 = General call address disabled
    Symbol F_ACKSTAT2 = SSP2CON2.6  ' Acknowledge Status bit (in I2C mode only)
        '1 = Acknowledge was not received
        '0 = Acknowledge was received
    Symbol F_ACKDT2 = SSP2CON2.5     ' Acknowledge Data bit (in I2C mode only)
        'In Receive mode:
            'Value transmitted when the user initiates an Acknowledge sequence at the end of a receive
            '1 = Not Acknowledge
            '0 = Acknowledge
    Symbol F_ACKEN2= SSP2CON2.4     '(1): Acknowledge Sequence Enable bit (in I2C Master mode only)
        'In Master Receive mode:
            '1 = Initiate Acknowledge sequence on SDAx and SCLx pins, and transmit ACKDT data bit.
            'Automatically cleared by hardware.
            '0 = Acknowledge sequence idle
    Symbol F_RCEN2 = SSP2CON2.3      '(1): Receive Enable bit (in I2C Master mode only)
        '1 = Enables Receive mode for I2C
        '0 = Receive idle
    Symbol F_PEN2 = SSP2CON2.2       '(1) Stop Condition Enable bit (in I2C Master mode only)
        'SCKx Release Control:
        '1 = Initiate Stop condition on SDAx and SCLx pins. Automatically cleared by hardware.
        '0 = Stop condition Idle
    Symbol F_RSEN2 = SSP2CON2.1      '(1): Repeated Start Condition Enabled bit (in I2C Master mode only)
        '1 = Initiate Repeated Start condition on SDAx and SCLx pins. Automatically cleared by hardware.
        '0 = Repeated Start condition Idle
    Symbol F_SEN2 = SSP2CON2.0       '(1): Start Condition Enabled bit (in I2C Master mode only)
        'In Master mode:
            '1 = Initiate Start condition on SDAx and SCLx pins. Automatically cleared by hardware.
            '0 = Start condition Idle
        'In Slave mode:
            '1 = Clock stretching is enabled for both slave transmit and slave receive (stretch enabled)
            '0 = Clock stretching is disabled
'
'Note 1: For bits ACKEN, RCEN, PEN, RSEN, SEN: If the I2C module is not in the Idle mode,
'        this bit may not be set (no spooling) and the SSPxBUF may not be written
'       (or writes to the SSPxBUF are disabled).
$endif
'-------------------------------------------------------------------------------
'22/08/2012
'SSP1CON3: SSP1 CONTROL REGISTER 3
    Symbol F_ACKTIM1 = SSP1CON3.7    ' Acknowledge Time Status bit (I2C mode only)(3)
        '1 = Indicates the I2C bus is in an Acknowledge sequence, set on 8th falling edge of SCLx clock
        '0 = Not an Acknowledge sequence, cleared on 9th rising edge of SCLx clock
    Symbol F_PCIE1 = SSP1CON3.6      ' Stop Condition Interrupt Enable bit (I2C mode only)
        '1 = Enable interrupt on detection of Stop condition
        '0 = Stop detection interrupts are disabled(2)
    Symbol F_SCIE1 = SSP1CON3.5      ' Start Condition Interrupt Enable bit (I2C mode only)
        '1 = Enable interrupt on detection of Start or Restart conditions
        '0 = Start detection interrupts are disabled(2)
    Symbol F_BOEN1 = SSP1CON3.4      ' Buffer Overwrite Enable bit
        'In SPI Slave mode:(1)
            '1 = SSPxBUF updates every time that a new data byte is shifted in ignoring the BF bit
            '0 = If new byte is received with BF bit of the SSPxSTAT register already set, SSPxOV bit of the
            'SSPxCON1 register is set, and the buffer is not updated
        'In I2C Master mode:
            'This bit is ignored.
        'In I2C Slave mode:
            '1 = SSPxBUF is updated and ACK is generated for a received address/data byte, ignoring the
            '    state of the SSPxOV bit only if the BF bit = 0.
            '0 = SSPxBUF is only updated when SSPxOV is clear
    Symbol F_SDAHT1 = SSP1CON3.3     ' SDAx Hold Time Selection bit (I2C mode only)
        '1 = Minimum of 300 ns hold time on SDAx after the falling edge of SCLx
        '0 = Minimum of 100 ns hold time on SDAx after the falling edge of SCLx
    Symbol F_SBCDE1 = SSP1CON3.2     ' Slave Mode Bus Collision Detect Enable bit (I2C Slave mode only)
        'If on the rising edge of SCLx, SDAx is sampled low when the module is outputting a high state, the
        'BCLxIF bit of the PIR2 register is set, and bus goes idle
            '1 = Enable slave bus collision interrupts
            '0 = Slave bus collision interrupts are disabled
    Symbol F_AHEN1 = SSP1CON3.1      ' Address Hold Enable bit (I2C Slave mode only)
            '1 = Following the 8th falling edge of SCLx for a matching received address byte; CKP bit of the
            '    SSPxCON1 register will be cleared and the SCLx will be held low.
            '0 = Address holding is disabled
    Symbol F_DHEN1 = SSP1CON3.0      ' Data Hold Enable bit (I2C Slave mode only)
        '1 = Following the 8th falling edge of SCLx for a received data byte; slave hardware clears the CKP bit
        '    of the SSPxCON1 register and SCLx is held low.
        '0 = Data holding is disabled
'
'Note 1: For daisy-chained SPI operation; allows the user to ignore all but the last
'        received byte. SSPxOV is still set when a new byte is received and BF = 1,
'        but hardware continues to write the most recent byte to SSPxBUF.
'     2: This bit has no effect in Slave modes for which Start and Stop condition
'        detection is explicitly listed as enabled.
'     3: The ACKTIM Status bit is active only when the AHEN bit or DHEN bit is set.
'-------------------------------------------------------------------------------
'22/08/2012
'SSP2CON3: SSP2 CONTROL REGISTER 3
    Symbol F_ACKTIM2 = SSP2CON3.7    ' Acknowledge Time Status bit (I2C mode only)(3)
        '1 = Indicates the I2C bus is in an Acknowledge sequence, set on 8th falling edge of SCLx clock
        '0 = Not an Acknowledge sequence, cleared on 9th rising edge of SCLx clock
    Symbol F_PCIE2 = SSP2CON3.6      ' Stop Condition Interrupt Enable bit (I2C mode only)
        '1 = Enable interrupt on detection of Stop condition
        '0 = Stop detection interrupts are disabled(2)
    Symbol F_SCIE2 = SSP2CON3.5      ' Start Condition Interrupt Enable bit (I2C mode only)
        '1 = Enable interrupt on detection of Start or Restart conditions
        '0 = Start detection interrupts are disabled(2)
    Symbol F_BOEN2 = SSP2CON3.4      ' Buffer Overwrite Enable bit
        'In SPI Slave mode:(1)
            '1 = SSPxBUF updates every time that a new data byte is shifted in ignoring the BF bit
            '0 = If new byte is received with BF bit of the SSPxSTAT register already set, SSPxOV bit of the
            'SSPxCON1 register is set, and the buffer is not updated
        'In I2C Master mode:
            'This bit is ignored.
        'In I2C Slave mode:
            '1 = SSPxBUF is updated and ACK is generated for a received address/data byte, ignoring the
            '    state of the SSPxOV bit only if the BF bit = 0.
            '0 = SSPxBUF is only updated when SSPxOV is clear
    Symbol F_SDAHT2 = SSP2CON3.3     ' SDAx Hold Time Selection bit (I2C mode only)
        '1 = Minimum of 300 ns hold time on SDAx after the falling edge of SCLx
        '0 = Minimum of 100 ns hold time on SDAx after the falling edge of SCLx
    Symbol F_SBCDE2 = SSP2CON3.2     ' Slave Mode Bus Collision Detect Enable bit (I2C Slave mode only)
        'If on the rising edge of SCLx, SDAx is sampled low when the module is outputting a high state, the
        'BCLxIF bit of the PIR2 register is set, and bus goes idle
            '1 = Enable slave bus collision interrupts
            '0 = Slave bus collision interrupts are disabled
    Symbol F_AHEN2 = SSP2CON3.1      ' Address Hold Enable bit (I2C Slave mode only)
            '1 = Following the 8th falling edge of SCLx for a matching received address byte; CKP bit of the
            '    SSPxCON1 register will be cleared and the SCLx will be held low.
            '0 = Address holding is disabled
    Symbol F_DHEN2 = SSP2CON3.0      ' Data Hold Enable bit (I2C Slave mode only)
        '1 = Following the 8th falling edge of SCLx for a received data byte; slave hardware clears the CKP bit
        '    of the SSPxCON1 register and SCLx is held low.
        '0 = Data holding is disabled
'
'Note 1: For daisy-chained SPI operation; allows the user to ignore all but the last
'        received byte. SSPxOV is still set when a new byte is received and BF = 1,
'        but hardware continues to write the most recent byte to SSPxBUF.
'     2: This bit has no effect in Slave modes for which Start and Stop condition
'        detection is explicitly listed as enabled.
'     3: The ACKTIM Status bit is active only when the AHEN bit or DHEN bit is set.
'-------------------------------------------------------------------------------
'22/08/2012
'SSPxMSK: SSPx MASK REGISTER
    'bit 7-1 MSK<7:1>: Mask bits
        '1 = The received address bit n is compared to SSPxADD<n> to detect I2C address match
        '0 = The received address bit n is not used to detect I2C address match
    'bit 0 MSK<0>: Mask bit for I2C Slave mode, 10-bit Address
        'I2C Slave mode, 10-bit address (SSPxM<3:0> = 0111 or 1111):
            '1 = The received address bit 0 is compared to SSPxADD<0> to detect I2C address match
            '0 = The received address bit 0 is not used to detect I2C address match
        'I2C Slave mode, 7-bit address, the bit is ignored
'-------------------------------------------------------------------------------
'22/08/2012
'SSPXADD: MSSPx ADDRESS AND BAUD RATE REGISTER (I2C MODE)
    'Master mode:
    'bit 7-0 ADD<7:0>: Baud Rate Clock Divider bits
        'SCLx pin clock period = ((ADD<7:0> + 1) *4)/FOSC
        '10-Bit Slave mode  Most Significant Address byte:
    'bit 7-3 Not used: Unused for Most Significant Address byte. Bit state of this
        ' register is a dont care. Bit pattern sent by master is fixed by I2C
        ' specification and must be equal to 11110. However, those bits are
        ' compared by hardware and are not affected by the value in this register.
    'bit 2-1 ADD<2:1>: Two Most Significant bits of 10-bit address
        'bit 0 Not used: Unused in this mode. Bit state is a dont care.
        '10-Bit Slave mode  Least Significant Address byte:
    'bit 7-0 ADD<7:0>: Eight Least Significant bits of 10-bit address
        '7-Bit Slave mode:
    'bit 7-1 ADD<7:1>: 7-bit address
        'bit 0 Not used: Unused in this mode. Bit state is a dont care.
'-------------------------------------------------------------------------------
'22/08/2012
'TXSTA1: TRANSMIT STATUS AND CONTROL REGISTER
    Symbol F_CSRC1 = TXSTA1.7        ' Clock Source Select bit
    Symbol F_CSRC = TXSTA1.7         ' Clock Source Select bit
        'Asynchronous mode:
            'Dont care
        'Synchronous mode:
            '1 = Master mode (clock generated internally from BRG)
            '0 = Slave mode (clock from external source)
    Symbol F_TX91 = TXSTA1.6         ' 9-bit Transmit Enable bit
    Symbol F_TX9 = TXSTA1.6          ' 9-bit Transmit Enable bit
        '1 = Selects 9-bit transmission
        '0 = Selects 8-bit transmission
    Symbol F_TXEN1 = TXSTA1.5        ' Transmit Enable bit(1)
    Symbol F_TXEN = TXSTA1.5         ' Transmit Enable bit(1)
        '1 = Transmit enabled
        '0 = Transmit disabled
    Symbol F_SYNC1 = TXSTA1.4        ' EUSART Mode Select bit
    Symbol F_SYNC = TXSTA1.4        ' EUSART Mode Select bit
        '1 = Synchronous mode
        '0 = Asynchronous mode
    Symbol F_SENDB1 = TXSTA1.3       ' Send Break Character bit
        'Asynchronous mode:
            '1 = Send Sync Break on next transmission (cleared by hardware upon completion)
            '0 = Sync Break transmission completed
        'Synchronous mode:
            'Dont care
    Symbol F_BRGH1 = TXSTA1.2        ' High Baud Rate Select bit
    Symbol F_BRGH = TXSTA1.2         ' High Baud Rate Select bit
        'Asynchronous mode:
            '1 = High speed
            '0 = Low speed
        'Synchronous mode:
            'Unused in this mode
    Symbol F_TRMT1 = TXSTA1.1        ' Transmit Shift Register Status bit
    Symbol F_TRMT = TXSTA1.1         ' Transmit Shift Register Status bit
        '1 = TSR empty
        '0 = TSR full
    Symbol F_TX9D1 = TXSTA1.0        ' Ninth bit of Transmit Data
    Symbol F_TX9D = TXSTA1.0         ' Ninth bit of Transmit Data
        'Can be address/data bit or a parity bit.
'
'Note 1: SREN/CREN overrides TXEN in Sync mode.
'-------------------------------------------------------------------------------
'22/08/2012
'TXSTA2: TRANSMIT STATUS AND CONTROL REGISTER
    Symbol F_CSRC2 = TXSTA2.7        ' Clock Source Select bit
        'Asynchronous mode:
            'Dont care
        'Synchronous mode:
            '1 = Master mode (clock generated internally from BRG)
            '0 = Slave mode (clock from external source)
    Symbol F_TX92 = TXSTA2.6         ' 9-bit Transmit Enable bit
        '1 = Selects 9-bit transmission
        '0 = Selects 8-bit transmission
    Symbol F_TXEN2 = TXSTA2.5        ' Transmit Enable bit(1)
        '1 = Transmit enabled
        '0 = Transmit disabled
    Symbol F_SYNC2 = TXSTA2.4        ' EUSART Mode Select bit
        '1 = Synchronous mode
        '0 = Asynchronous mode
    Symbol F_SENDB2 = TXSTA2.3       ' Send Break Character bit
        'Asynchronous mode:
            '1 = Send Sync Break on next transmission (cleared by hardware upon completion)
            '0 = Sync Break transmission completed
        'Synchronous mode:
            'Dont care
    Symbol F_BRGH2 = TXSTA2.2        ' High Baud Rate Select bit
        'Asynchronous mode:
            '1 = High speed
            '0 = Low speed
        'Synchronous mode:
            'Unused in this mode
    Symbol F_TRMT2 = TXSTA2.1        ' Transmit Shift Register Status bit
        '1 = TSR empty
        '0 = TSR full
    Symbol F_TX9D2 = TXSTA2.0        ' Ninth bit of Transmit Data
        'Can be address/data bit or a parity bit.
'
'Note 1: SREN/CREN overrides TXEN in Sync mode.
'-------------------------------------------------------------------------------
'22/08/2012
'RCSTA1: RECEIVE STATUS AND CONTROL REGISTER
    Symbol F_SPEN1 = RCSTA1.7        ' Serial Port Enable bit
    Symbol F_SPEN = RCSTA1.7         ' Serial Port Enable bit
        '1 = Serial port enabled (configures RXx/DTx and TXx/CKx pins as serial port pins)
        '0 = Serial port disabled (held in Reset)
    Symbol F_RX91 = RCSTA1.6         ' 9-bit Receive Enable bit
    Symbol F_RX9 = RCSTA1.6          ' 9-bit Receive Enable bit
        '1 = Selects 9-bit reception
        '0 = Selects 8-bit reception
    Symbol F_SREN1 = RCSTA1.5        ' Single Receive Enable bit
    Symbol F_SREN = RCSTA1.5        ' Single Receive Enable bit
        'Asynchronous mode:
            'Dont care
        'Synchronous mode  Master:
            '1 = Enables single receive
            '0 = Disables single receive
            'This bit is cleared after reception is complete.
        'Synchronous mode  Slave
            'Dont care
    Symbol F_CREN1 = RCSTA1.4        ' Continuous Receive Enable bit
    Symbol F_CREN = RCSTA1.4        ' Continuous Receive Enable bit
        'Asynchronous mode:
            '1 = Enables receiver
            '0 = Disables receiver
        'Synchronous mode:
            '1 = Enables continuous receive until enable bit CREN is cleared (CREN overrides SREN)
            '0 = Disables continuous receive
    Symbol F_ADDEN1 = RCSTA1.3       ' Address Detect Enable bit
    Symbol F_ADDEN = RCSTA1.3       ' Address Detect Enable bit
        'Asynchronous mode 9-bit (RX9 = 1):
            '1 = Enables address detection, enable interrupt and load the receive buffer when RSR<8> is set
            '0 = Disables address detection, all bytes are received and ninth bit can be used as parity bit
        'Asynchronous mode 8-bit (RX9 = 0):
            'Dont care
    Symbol F_FERR1 = RCSTA1.2        ' Framing Error bit
    Symbol F_FERR = RCSTA1.2        ' Framing Error bit
        '1 = Framing error (can be updated by reading RCREGx register and receive next valid byte)
        '0 = No framing error
    Symbol F_OERR1 = RCSTA1.1        ' Overrun Error bit
    Symbol F_OERR = RCSTA1.1        ' Overrun Error bit
        '1 = Overrun error (can be cleared by clearing bit CREN)
        '0 = No overrun error
    Symbol F_RX9D1 = RCSTA1.0        ' Ninth bit of Received Data
    Symbol F_RX9D = RCSTA1.0        ' Ninth bit of Received Data
        'This can be address/data bit or a parity bit and must be calculated by user firmware.
'-------------------------------------------------------------------------------
'22/08/2012
'RCSTA2: RECEIVE STATUS AND CONTROL REGISTER
    Symbol F_SPEN2 = RCSTA2.7        ' Serial Port Enable bit
        '1 = Serial port enabled (configures RXx/DTx and TXx/CKx pins as serial port pins)
        '0 = Serial port disabled (held in Reset)
    Symbol F_RX92 = RCSTA2.6         ' 9-bit Receive Enable bit
        '1 = Selects 9-bit reception
        '0 = Selects 8-bit reception
    Symbol F_SREN2 = RCSTA2.5        ' Single Receive Enable bit
        'Asynchronous mode:
            'Dont care
        'Synchronous mode  Master:
            '1 = Enables single receive
            '0 = Disables single receive
            'This bit is cleared after reception is complete.
        'Synchronous mode  Slave
            'Dont care
    Symbol F_CREN2 = RCSTA2.4        ' Continuous Receive Enable bit
        'Asynchronous mode:
            '1 = Enables receiver
            '0 = Disables receiver
        'Synchronous mode:
            '1 = Enables continuous receive until enable bit CREN is cleared (CREN overrides SREN)
            '0 = Disables continuous receive
    Symbol F_ADDEN2 = RCSTA2.3       ' Address Detect Enable bit
        'Asynchronous mode 9-bit (RX9 = 1):
            '1 = Enables address detection, enable interrupt and load the receive buffer when RSR<8> is set
            '0 = Disables address detection, all bytes are received and ninth bit can be used as parity bit
        'Asynchronous mode 8-bit (RX9 = 0):
            'Dont care
    Symbol F_FERR2 = RCSTA2.2        ' Framing Error bit
        '1 = Framing error (can be updated by reading RCREGx register and receive next valid byte)
        '0 = No framing error
    Symbol F_OERR2 = RCSTA2.1        ' Overrun Error bit
        '1 = Overrun error (can be cleared by clearing bit CREN)
        '0 = No overrun error
    Symbol F_RX9D2 = RCSTA2.0        ' Ninth bit of Received Data
        'This can be address/data bit or a parity bit and must be calculated by user firmware.
'-------------------------------------------------------------------------------
'22/08/2012
'BAUDCON1: BAUD RATE CONTROL REGISTER
    Symbol F_ABDOVF1 = BAUDCON1.7    ' Auto-Baud Detect Overflow bit
        'Asynchronous mode:
            '1 = Auto-baud timer overflowed
            '0 = Auto-baud timer did not overflow
        'Synchronous mode:
            'Dont care
    Symbol F_RCIDL1 = BAUDCON1.6     ' Receive Idle Flag bit
        'Asynchronous mode:
            '1 = Receiver is Idle
            '0 = Start bit has been detected and the receiver is active
        'Synchronous mode:
            'Dont care
    Symbol F_DTRXP1 = BAUDCON1.5     ' Data/Receive Polarity Select bit
        'Asynchronous mode:
            '1 = Receive data (RXx) is inverted (active-low)
            '0 = Receive data (RXx) is not inverted (active-high)
        'Synchronous mode:
            '1 = Data (DTx) is inverted (active-low)
            '0 = Data (DTx) is not inverted (active-high)
    Symbol F_CKTXP1 = BAUDCON1.4     ' Clock/Transmit Polarity Select bit
        'Asynchronous mode:
            '1 = Idle state for transmit (TXx) is low
            '0 = Idle state for transmit (TXx) is high
        'Synchronous mode:
            '1 = Data changes on the falling edge of the clock and is sampled on the rising edge of the clock
            '0 = Data changes on the rising edge of the clock and is sampled on the falling edge of the clock
    Symbol F_BRG161 = BAUDCON1.3     ' 16-bit Baud Rate Generator bit
        '1 = 16-bit Baud Rate Generator is used (SPBRGHx:SPBRGx)
        '0 = 8-bit Baud Rate Generator is used (SPBRGx)
    'bit 2 Unimplemented: Read as 0
    Symbol F_WUE1 = BAUDCON1.1       ' Wake-up Enable bit
        'Asynchronous mode:
            '1 = Receiver is waiting for a falling edge. No character will be received
            ' but RCxIF will be set on the falling edge. WUE will automatically clear on the rising edge.
            '0 = Receiver is operating normally
        'Synchronous mode:
            'Dont care
    Symbol F_ABDEN1 = BAUDCON1.0     ' Auto-Baud Detect Enable bit
        'Asynchronous mode:
            '1 = Auto-Baud Detect mode is enabled (clears when auto-baud is complete)
            '0 = Auto-Baud Detect mode is disabled
        'Synchronous mode:
            'Dont care
'-------------------------------------------------------------------------------
'22/08/2012
'BAUDCON2: BAUD RATE CONTROL REGISTER
    Symbol F_ABDOVF2 = BAUDCON2.7    ' Auto-Baud Detect Overflow bit
        'Asynchronous mode:
            '1 = Auto-baud timer overflowed
            '0 = Auto-baud timer did not overflow
        'Synchronous mode:
            'Dont care
    Symbol F_RCIDL2 = BAUDCON2.6     ' Receive Idle Flag bit
        'Asynchronous mode:
            '1 = Receiver is Idle
            '0 = Start bit has been detected and the receiver is active
        'Synchronous mode:
            'Dont care
    Symbol F_DTRXP2 = BAUDCON2.5     ' Data/Receive Polarity Select bit
        'Asynchronous mode:
            '1 = Receive data (RXx) is inverted (active-low)
            '0 = Receive data (RXx) is not inverted (active-high)
        'Synchronous mode:
            '1 = Data (DTx) is inverted (active-low)
            '0 = Data (DTx) is not inverted (active-high)
    Symbol F_CKTXP2 = BAUDCON2.4     ' Clock/Transmit Polarity Select bit
        'Asynchronous mode:
            '1 = Idle state for transmit (TXx) is low
            '0 = Idle state for transmit (TXx) is high
        'Synchronous mode:
            '1 = Data changes on the falling edge of the clock and is sampled on the rising edge of the clock
            '0 = Data changes on the rising edge of the clock and is sampled on the falling edge of the clock
    Symbol F_BRG162 = BAUDCON2.3     ' 16-bit Baud Rate Generator bit
        '1 = 16-bit Baud Rate Generator is used (SPBRGHx:SPBRGx)
        '0 = 8-bit Baud Rate Generator is used (SPBRGx)
    'bit 2 Unimplemented: Read as 0
    Symbol F_WUE2 = BAUDCON2.1       ' Wake-up Enable bit
        'Asynchronous mode:
            '1 = Receiver is waiting for a falling edge. No character will be received
            ' but RCxIF will be set on the falling edge. WUE will automatically clear on the rising edge.
            '0 = Receiver is operating normally
        'Synchronous mode:
            'Dont care
    Symbol F_ABDEN2 = BAUDCON2.0     ' Auto-Baud Detect Enable bit
        'Asynchronous mode:
            '1 = Auto-Baud Detect mode is enabled (clears when auto-baud is complete)
            '0 = Auto-Baud Detect mode is disabled
        'Synchronous mode:
            'Dont care
'-------------------------------------------------------------------------------
'22/08/2012
'ADCON0: A/D CONTROL REGISTER 0
    'bit 7 Unimplemented: Read as 0
    'bit 6-2 CHS<4:0>: Analog Channel Select bits
        '00000 = AN0
        '00001 = AN1
        '00010 = AN2
        '00011 = AN3
        '00100 = AN4
        '00101 = AN5(1)
        '00110 = AN6(1)
        '00111 = AN7(1)
        '01000 = AN8
        '01001 = AN9
        '01010 = AN10
        '01011 = AN11
        '01100 = AN12
        '01101 = AN13
        '01110 = AN14
        '01111 = AN15
        '10000 = AN16
        '10001 = AN17
        '10010 = AN18
        '10011 = AN19
        '10100 = AN20(1)
        '10101 = AN21(1)
        '10110 = AN22(1)
        '10111 = AN23(1)
        '11000 = AN24(1)
        '11001 = AN25(1)
        '11010 = AN26(1)
        '11011 = AN27(1)
        '11100 = Reserved
        '11101 = CTMU
        '11110 = DAC
        '11111 = FVR BUF2 (1.024V/2.048V/2.096V Volt Fixed Voltage Reference)(2)
    Symbol F_GO_DONE = ADCON0.1         ' A/D Conversion Status bit
    Symbol F_GO_Not_DONE = ADCON0.1     ' A/D Conversion Status bit
        '1 = A/D conversion cycle in progress. Setting this bit starts an A/D conversion cycle.
        '        This bit is automatically cleared by hardware when the A/D
        '        conversion has completed.
        '0 = A/D conversion completed/not in progress
    Symbol F_ADON = ADCON0.0            ' ADC Enable bit
        '1 = ADC is enabled
        '0 = ADC is disabled and consumes no operating current
'
'Note 1: Available on PIC18(L)F4XK22 devices only.
'     2: Allow greater than 15 uS acquisition time when measuring the Fixed Voltage Reference.
'-------------------------------------------------------------------------------
'22/08/2012
'ADCON1: A/D CONTROL REGISTER 1
    Symbol F_TRIGSEL = ADCON1.7     ' Special Trigger Select bit
        '1 = Selects the special trigger from CTMU
        '0 = Selects the special trigger from CCP5
    'bit 6-4 Unimplemented: Read as 0
    Symbol F_PVCFG1 = ADCON1.3      ' <1>: Positive Voltage Reference Configuration bits
    Symbol F_PVCFG0 = ADCON1.2      ' <0>: Positive Voltage Reference Configuration bits
        '00 = A/D VREF+ connected to internal signal, AVDD
        '01 = A/D VREF+ connected to external pin, VREF+
        '10 = A/D VREF+ connected to internal signal, FVR BUF2
        '11 = Reserved (by default, A/D VREF+ connected to internal signal, AVDD)
    Symbol F_NVCFG01 = ADCON1.1     '<1>: Negative Voltage Reference Configuration bits
    Symbol F_NVCFG00 = ADCON1.0     '<0>: Negative Voltage Reference Configuration bits
        '00 = A/D VREF- connected to internal signal, AVSS
        '01 = A/D VREF- connected to external pin, VREF-
        '10 = Reserved (by default, A/D VREF+ connected to internal signal, AVSS)
        '11 = Reserved (by default, A/D VREF+ connected to internal signal, AVSS)
'-------------------------------------------------------------------------------
'22/08/2012
'ADCON2: A/D CONTROL REGISTER 2
    Symbol F_ADFM = ADCON2.7        ' A/D Conversion Result Format Select bit
        '1 = Right justified
        '0 = Left justified
    'bit 6 Unimplemented: Read as 0
    'bit 5-3 ACQT<2:0>: A/D Acquisition time select bits. Acquisition time is the
    '       duration that the A/D charge holding capacitor remains connected to A/D 
    '       channel from the instant the GO/DONE bit is set until conversions begins.
        '000 = 0(1)
        '001 = 2 TAD
        '010 = 4 TAD
        '011 = 6 TAD
        '100 = 8 TAD
        '101 = 12 TAD
        '110 = 16 TAD
        '111 = 20 TAD
    'bit 2-0 ADCS<2:0>: A/D Conversion Clock Select bits
        '000 = FOSC/2
        '001 = FOSC/8
        '010 = FOSC/32
        '011 = FRC(1) (clock derived from a dedicated internal oscillator = 600 kHz nominal)
        '100 = FOSC/4
        '101 = FOSC/16
        '110 = FOSC/64
        '111 = FRC(1) (clock derived from a dedicated internal oscillator = 600 kHz nominal)
'
'Note 1: When the A/D clock source is selected as FRC then the start of conversion
'       is delayed by one instruction 'cycle after the GO/DONE bit is set to allow
'       the SLEEP instruction to be executed.
'-------------------------------------------------------------------------------
'22/08/2012
'CM1CON0: COMPARATOR 1 CONTROL REGISTER
    Symbol F_C1ON = CM1CON0.7   ' Comparator C1 Enable bit
        '1 = Comparator C1 is enabled
        '0 = Comparator C1 is disabled
    Symbol F_C1OUT = CM1CON0.6  ' Comparator C1 Output bit
        'If C1POL = 1 (inverted polarity):
            'C1OUT = 0 when C1VIN+ > C1VINC1OUT
            '= 1 when C1VIN+ < C1VINIf
                'C1POL = 0 (non-inverted polarity):
                'C1OUT = 1 when C1VIN+ > C1VINC1OUT
            '= 0 when C1VIN+ < C1VINbit
    Symbol F_C1OE = CM1CON0.5   ' Comparator C1 Output Enable bit
        '1 = C1OUT is present on the C1OUT pin(1)
        '0 = C1OUT is internal only
    Symbol F_C1POL = CM1CON0.4  ' Comparator C1 Output Polarity Select bit
        '1 = C1OUT logic is inverted
        '0 = C1OUT logic is not inverted
    Symbol F_C1SP = CM1CON0.3   ' Comparator C1 Speed/Power Select bit
        '1 = C1 operates in normal power, higher speed mode
        '0 = C1 operates in low-power, low-speed mode
    Symbol F_C1R = CM1CON0.2    ' Comparator C1 Reference Select bit (non-inverting input)
        '1 = C1VIN+ connects to C1VREF output
        '0 = C1VIN+ connects to C12IN+ pin
    Symbol F_C1CH1 = CM1CON0.1  '<1:0>: Comparator C1 Channel Select Bit
    Symbol F_C1CH0 = CM1CON0.0  '<1:0>: Comparator C1 Channel Select Bit
        '00 = C12IN0- pin of C1 connects to C1VIN-
        '01 = C12IN1- pin of C1 connects to C1VIN-
        '10 = C12IN2- pin of C1 connects to C1VIN-
        '11 = C12IN3- pin of C1 connects to C1VINNote
'
'Note1: Comparator output requires the following three conditions:
'       C1OE = 1, C1ON = 1 and corresponding port TRIS bit = 0.
'-------------------------------------------------------------------------------
'22/08/2012
'CM2CON: COMPARATOR 2 CONTROL REGISTER
    Symbol F_C2ON = CM2CON.7        ' Comparator C2 Enable bit
        '1 = Comparator C2 is enabled
        '0 = Comparator C2 is disabled
    Symbol F_C2OUT = CM2CON.6       ' Comparator C2 Output bit
        'If C2POL = 1 (inverted polarity):
            'C2OUT = 0 when C2VIN+ > C2VINC2OUT
            '= 1 when C2VIN+ < C2VINIf
                'C2POL = 0 (non-inverted polarity):
            'C2OUT = 1 when C2VIN+ > C2VINC2OUT
                '= 0 when C2VIN+ < C2VINbit
    Symbol F_C2OE = CM2CON.5        ' Comparator C2 Output Enable bit
        '1 = C2OUT is present on C2OUT pin(1)
        '0 = C2OUT is internal only
    Symbol F_C2POL = CM2CON.4       ' Comparator C2 Output Polarity Select bit
        '1 = C2OUT logic is inverted
        '0 = C2OUT logic is not inverted
    Symbol F_C2SP = CM2CON.3        ' Comparator C2 Speed/Power Select bit
        '1 = C2 operates in normal power, higher speed mode
        '0 = C2 operates in low-power, low-speed mode
    Symbol F_C2R = CM2CON.2         ' Comparator C2 Reference Select bits (non-inverting input)
        '1 = C2VIN+ connects to C2VREF
        '0 = C2VIN+ connects to C2IN+ pin
    Symbol F_C2CH1 = CM2CON.1        '<1>: Comparator C2 Channel Select bits
    Symbol F_C2CH0 = CM2CON.0        '<0>: Comparator C2 Channel Select bits
        '00 = C12IN0- pin of C2 connects to C2VIN-
        '01 = C12IN1- pin of C2 connects to C2VIN-
        '10 = C12IN2- pin of C2 connects to C2VIN-
        '11 = C12IN3- pin of C2 connects to C2VINNote
'
'Note1: Comparator output requires the following three conditions:
'       C2OE = 1, C2ON = 1 and corresponding port TRIS bit = 0.
'-------------------------------------------------------------------------------
'22/08/2012
'CM2CON1: COMPARATOR 1 AND 2 CONTROL REGISTER
    'bit 7 MC1OUT: Mirror Copy of C1OUT bit
    'bit 6 MC2OUT: Mirror Copy of C2OUT bit
    Symbol F_C1RSEL = CM2CON1.5     ' Comparator C1 Reference Select bit
        '1 = FVR BUF1 routed to C1VREF input
        '0 = DAC routed to C1VREF input
    Symbol F_C2RSEL = CM2CON1.4     ' Comparator C2 Reference Select bit
        '1 = FVR BUF1 routed to C2VREF input
        '0 = DAC routed to C2VREF input
    Symbol F_C1HYS = CM2CON1.3      ' Comparator C1 Hysteresis Enable bit
        '1 = Comparator C1 hysteresis enabled
        '0 = Comparator C1 hysteresis disabled
    Symbol F_C2HYS = CM2CON1.2      ' Comparator C2 Hysteresis Enable bit
        '1 = Comparator C2 hysteresis enabled
        '0 = Comparator C2 hysteresis disabled
    Symbol F_C1SYNC = CM2CON1.1     ' C1 Output Synchronous Mode bit
        '1 = C1 output is synchronized to rising edge of TMR1 clock (T1CLK)
        '0 = C1 output is asynchronous
    Symbol F_C2SYNC = CM2CON1.0     ' C2 Output Synchronous Mode bit
        '1 = C2 output is synchronized to rising edge of TMR1 clock (T1CLK)
        '0 = C2 output is asynchronous
'-------------------------------------------------------------------------------
'22/08/2012
$ifdef __CTMUCONH
'CTMUCONH: CTMU CONTROL REGISTER 0
    Symbol F_CTMUEN = CTMUCONH.7    ' CTMU Enable bit
        '1 = Module is enabled
        '0 = Module is disabled
    'bit 6 Unimplemented: Read as 0
    Symbol F_CTMUSIDL = CTMUCONH.5  ' Stop in Idle Mode bit
        '1 = Discontinue module operation when device enters Idle mode
        '0 = Continue module operation in Idle mode
    Symbol F_TGEN = CTMUCONH.4      ' Time Generation Enable bit
        '1 = Enables edge delay generation
        '0 = Disables edge delay generation
    Symbol F_EDGEN = CTMUCONH.3     ' Edge Enable bit
        '1 = Edges are not blocked
        '0 = Edges are blocked
    Symbol F_EDGSEQEN = CTMUCONH.2  ' Edge Sequence Enable bit
        '1 = Edge 1 event must occur before Edge 2 event can occur
        '0 = No edge sequence is needed
    Symbol F_IDISSEN = CTMUCONH.1   ' Analog Current Source Control bit
        '1 = Analog current source output is grounded
        '0 = Analog current source output is not grounded
    Symbol F_CTTRIG = CTMUCONH.0    ' CTMU Special Event Trigger Control Bit
        '1 = CTMU Special Event Trigger is enabled
        '0 = CTMU Special Event Trigger is disabled
$endif
'-------------------------------------------------------------------------------
'22/08/2012
'CTMUCONL: CTMU CONTROL REGISTER 1
    Symbol F_EDG2POL = CTMUCONL.7   ' Edge 2 Polarity Select bit
        '1 = Edge 2 programmed for a positive edge response
        '0 = Edge 2 programmed for a negative edge response
    Symbol F_EDG2SEL1 = CTMUCONL.6  '<1>: Edge 2 Source Select bits
    Symbol F_EDG2SEL0 = CTMUCONL.5  '<0>: Edge 2 Source Select bits
        '11 = CTED1 pin
        '10 = CTED2 pin
        '01 = ECCP1 Special Event Trigger
        '00 = ECCP2 Special Event Trigger
    Symbol F_EDG1POL = CTMUCONL.4   ' Edge 1 Polarity Select bit
        '1 = Edge 1 programmed for a positive edge response
        '0 = Edge 1 programmed for a negative edge response
    Symbol F_EDG1SEL1 = CTMUCONL.3  '<1>: Edge 1 Source Select bits
    Symbol F_EDG1SEL0 = CTMUCONL.2  '<0>: Edge 1 Source Select bits
        '11 = CTED1 pin
        '10 = CTED2 pin
        '01 = ECCP1 Special Event Trigger
        '00 = ECCP2 Special Event Trigger
    Symbol F_EDG2STAT = CTMUCONL.1  ' Edge 2 Status bit
        '1 = Edge 2 event has occurred
        '0 = Edge 2 event has not occurred
    Symbol F_EDG1STAT = CTMUCONL.0  ' Edge 1 Status bit
        '1 = Edge 1 event has occurred
        '0 = Edge 1 event has not occurred
'-------------------------------------------------------------------------------
'22/08/2012
'CTMUICON: CTMU CURRENT CONTROL REGISTER
    'bit 7-2 ITRIM<5:0>: Current Source Trim bits
        '011111 = Maximum positive change from nominal current
        '011110
        '...
        '000001 = Minimum positive change from nominal current
        '000000 = Nominal current output specified by IRNG<1:0>
        '111111 = Minimum negative change from nominal current
        '...
        '100010
        '100001 = Maximum negative change from nominal current
    Symbol F_IRNG1 = CTMUICON.1     '<1>: Current Source Range Select bits
    Symbol F_IRNG0 = CTMUICON.0     '<0>: Current Source Range Select bits
        '11 = 100 e Base current
        '10 = 10 e Base current
        '01 = Base current level (0.55 A nominal)
        '00 = Current source disabled
'-------------------------------------------------------------------------------
'22/08/2012
'SRCON0: SR LATCH CONTROL REGISTER
    Symbol F_SRLEN = SRCON0.7       ' SR Latch Enable bit(1)
        '1 = SR latch is enabled
        '0 = SR latch is disabled
    'bit 6-4 SRCLK<2:0>: SR Latch Clock Divider Bits
        '000 = Generates a 2 TOSC wide pulse on DIVSRCLK every 4 peripheral clock cycles
        '001 = Generates a 2 TOSC wide pulse on DIVSRCLK every 8 peripheral clock cycles
        '010 = Generates a 2 TOSC wide pulse on DIVSRCLK every 16 peripheral clock cycles
        '011 = Generates a 2 TOSC wide pulse on DIVSRCLK every 32 peripheral clock cycles
        '100 = Generates a 2 TOSC wide pulse on DIVSRCLK every 64 peripheral clock cycles
        '101 = Generates a 2 TOSC wide pulse on DIVSRCLK every 128 peripheral clock cycles
        '110 = Generates a 2 TOSC wide pulse on DIVSRCLK every 256 peripheral clock cycles
        '111 = Generates a 2 TOSC wide pulse on DIVSRCLK every 512 peripheral clock cycles
    Symbol F_SRQEN = SRCON0.3       ' SR Latch Q Output Enable bit
        '1 = Q is present on the SRQ pin
        '0 = Q is internal only
    Symbol F_SRNQEN = SRCON0.2      ' SR Latch Q Output Enable bit
        '1 = Q is present on the SRNQ pin
        '0 = Q is internal only
    Symbol F_SRPS = SRCON0.1        ' Pulse Set Input of the SR Latch bit(2)
        '1 = Pulse set input for 2 TOSC clock cycles
        '0 = No effect on set input
    Symbol F_SRPR = SRCON0.0        ' Pulse Reset Input of the SR Latch bit(2)
        '1 = Pulse reset input for 2 TOSC clock cycles
        '0 = No effect on Reset input
'
'Note 1: Changing the SRCLK bits while the SR latch is enabled may cause false triggers
'        to the set and Reset inputs of the latch.
'     2: Set only, always reads back 0.
'-------------------------------------------------------------------------------
'22/08/2012
'SRCON1: SR LATCH CONTROL REGISTER 1
    Symbol F_SRSPE = SRCON1.7       ' SR Latch Peripheral Set Enable bit
        '1 = SRI pin status sets SR Latch
        '0 = SRI pin status has no effect on SR Latch
    Symbol F_SRSCKE = SRCON1.6      ' SR Latch Set Clock Enable bit
        '1 = Set input of SR latch is pulsed with DIVSRCLK
        '0 = Set input of SR latch is not pulsed with DIVSRCLK
    Symbol F_SRSC2E = SRCON1.5      ' SR Latch C2 Set Enable bit
        '1 = C2 Comparator output sets SR Latch
        '0 = C2 Comparator output has no effect on SR Latch
    Symbol F_SRSC1E = SRCON1.4    ' SR Latch C1 Set Enable bit
        '1 = C1 Comparator output sets SR Latch
        '0 = C1 Comparator output has no effect on SR Latch
    Symbol F_SRRPE = SRCON1.3       ' SR Latch Peripheral Reset Enable bit
        '1 = SRI pin resets SR Latch
        '0 = SRI pin has no effect on SR Latch
    Symbol F_SRRCKE = SRCON1.2      ' SR Latch Reset Clock Enable bit
        '1 = Reset input of SR latch is pulsed with DIVSRCLK
        '0 = Reset input of SR latch is not pulsed with DIVSRCLK
    Symbol F_SRRC2E = SRCON1.1      ' SR Latch C2 Reset Enable bit
        '1 = C2 Comparator output resets SR Latch
        '0 = C2 Comparator output has no effect on SR Latch
    Symbol F_SRRC1E = SRCON1.0      ' SR Latch C1 Reset Enable bit
        '1 = C1 Comparator output resets SR Latch
        '0 = C1 Comparator output has no effect on SR Latch
'-------------------------------------------------------------------------------
'22/08/2012
'VREFCON0: FIXED VOLTAGE REFERENCE CONTROL REGISTER
    Symbol F_FVREN = VREFCON0.7     ' Fixed Voltage Reference Enable bit
        '0 = Fixed Voltage Reference is disabled
        '1 = Fixed Voltage Reference is enabled
    Symbol F_FVRST = VREFCON0.6     ' Fixed Voltage Reference Ready Flag bit
        '0 = Fixed Voltage Reference output is not ready or not enabled
        '1 = Fixed Voltage Reference output is ready for use
    Symbol F_FVRS1 = VREFCON0.5     ' <1>: Fixed Voltage Reference Selection bits
    Symbol F_FVRS0 = VREFCON0.4     ' <0>: Fixed Voltage Reference Selection bits
        '00 = Fixed Voltage Reference Peripheral output is off
        '01 = Fixed Voltage Reference Peripheral output is 1x (1.024V)
        '10 = Fixed Voltage Reference Peripheral output is 2x (2.048V)(1)
        '11 = Fixed Voltage Reference Peripheral output is 4x (4.096V)(1)
    'bit 3-2 Reserved: Read as 0. Maintain these bits clear.
    'bit 1-0 Unimplemented: Read as 0.
'
'Note 1: Fixed Voltage Reference output cannot exceed VDD.
'-------------------------------------------------------------------------------
'22/08/2012
'VREFCON1: VOLTAGE REFERENCE CONTROL REGISTER 0
    Symbol F_DACEN = VREFCON1.7     ' DAC Enable bit
        '1 = DAC is enabled
        '0 = DAC is disabled
    Symbol F_DACLPS = VREFCON1.6    ' DAC Low-Power Voltage Source Select bit
        '1 = DAC Positive reference source selected
        '0 = DAC Negative reference source selected
    Symbol F_DACOE = VREFCON1.5     ' DAC Voltage Output Enable bit
        '1 = DAC voltage level is also an output on the DACOUT pin
        '0 = DAC voltage level is disconnected from the DACOUT pin
    'bit 4 Unimplemented: Read as 0
    Symbol F_DACPSS1 = VREFCON1.3   '<1>: DAC Positive Source Select bits
    Symbol F_DACPSS0 = VREFCON1.2   '<0>: DAC Positive Source Select bits
        '00 = VDD
        '01 = VREF+
        '10 = FVR BUF1 output
        '11 = Reserved, do not use
    'bit 1 Unimplemented: Read as 0
    Symbol F_DACNSS = VREFCON1.0    ' DAC Negative Source Select bits
        '1 = VREF-
        '0 = VSS
'-------------------------------------------------------------------------------
'22/08/2012
'VREFCON2: VOLTAGE REFERENCE CONTROL REGISTER 1
    'bit 7-5 Unimplemented: Read as 0
    'bit 4-0 DACR<4:0>: DAC Voltage Output Select bits
        'VOUT = ((VSRC+) - (VSRC-))*(DACR<4:0>/(25)) + VSRC-
'-------------------------------------------------------------------------------
'22/08/2012
'HLVDCON: HIGH/LOW-VOLTAGE DETECT CONTROL REGISTER
    Symbol F_VDIRMAG = HLVDCON.7        ' Voltage Direction Magnitude Select bit
        '1 = Event occurs when voltage equals or exceeds trip point (HLVDL<3:0>)
        '0 = Event occurs when voltage equals or falls below trip point (HLVDL<3:0>)
    Symbol F_BGVST = HLVDCON.6          ' Band Gap Reference Voltages Stable Status Flag bit
        '1 = Internal band gap voltage references are stable
        '0 = Internal band gap voltage reference is not stable
    Symbol F_IRVST = HLVDCON.5          ' Internal Reference Voltage Stable Flag bit
        '1 = Indicates that the voltage detect logic will generate the interrupt flag at the specified voltage range
        '0 = Indicates that the voltage detect logic will not generate the interrupt
        '    flag at the specified voltage range and the HLVD interrupt should not be enabled
    Symbol F_HLVDEN = HLVDCON.4         ' High/Low-Voltage Detect Power Enable bit
        '1 = HLVD enabled
        '0 = HLVD disabled
    'bit 3-0 HLVDL<3:0>: Voltage Detection Level bits(1)
    Symbol F_HLVDL3 = HLVDCON.3         ' <3>: Voltage Detection Level bits(1)
    Symbol F_HLVDL2 = HLVDCON.2         ' <2>: Voltage Detection Level bits(1)
    Symbol F_HLVDL1 = HLVDCON.1         ' <1>: Voltage Detection Level bits(1)    
    Symbol F_HLVDL0 = HLVDCON.0         ' <0>: Voltage Detection Level bits(1)
        '1111 = External analog input is used (input comes from the HLVDIN pin)
        '1110 = Maximum setting
        '...
        '0000 = Minimum setting
'
'Note 1: See Table 27-4 for specifications.
'-------------------------------------------------------------------------------
'22/08/2012
' WDTCON: WATCHDOG TIMER CONTROL REGISTER
    ' bit 7-1 Unimplemented: Read as 0
    Symbol F_SWDTEN = WDTCON.0      ' Software Enable or Disable the Watchdog Timer bit(1)
    ' 1 = WDT is turned on
    ' 0 = WDT is turned off (Reset value)
    '
    ' Note 1: This bit has no effect if the Configuration bit, WDTEN, is enabled.
'******************************************************************** 
'ASCII characters  
    $ifndef _AMICUS18_INC
    Symbol Home = 1
    Symbol Bell = 7
    Symbol BkSp = 8
    Symbol Tab = 9
    Symbol CR = 13
    Symbol LF = $0A     ' Line Feed Char    
    Symbol True = 1     ' Boolean True
    Symbol False = 0    ' Boolean False
    Symbol Null = 0     ' Null character 
    Symbol ACK = 6
    Symbol STX = 2
    Symbol ETX = 3
    Symbol SPACE = $20
    Symbol DEL = 127    
    Symbol ESC = $1B    ' Escape
    Symbol BS = 08      ' Backspace           
    $endif
'********************************************************************
